# 代码风格确定
## 组件化
如果我们将一个页面中所有的处理逻辑全部放在一起，处理起来就会变得非常复杂，而且不利于后续的管理以及扩展。
但如果，我们将一个页面拆分成一个个小的功能块，每个功能块完成属于自己这部分独立的功能，那么之后整个页面的管理和维护就变得非常容易。
​它提供了一种抽象，让我们可以开发出一个个独立可复用的小组件来构造我们的应用。
任何的应用都会被抽象成一颗组件树。
组件化思想的应用：
​有了组件化的思想，我们在之后的开发中就要充分
尽可能的将页面拆分成一个个小的、可复用的组件
这样让我们的代码更加方便组织和管理，并且扩展性也更强
### 具体实现
对每个子页面进行拆分，并在主页面进行引用，个个子组件只完成当前子页面的功能，主页面负责衔接个个子组件，
## 逻辑函数化
对一个功能的实现，往往要有多个函数。而这些函数全部放在一个方法里会降低代码的可读性，项目会显得臃肿，某些地方会造成强耦合形成屎山
造成后续维护只能添加逻辑，原先的逻辑没人能维护的尴尬状况
### 函数柯里化
柯里化（Currying）是把接受多个参数的函数变换成接受一个单一参数(最初函数的第一个参数)的函数，并且返回接受余下的参数且返回结果的新函数的技术。这个技术以逻辑学家 Haskell Curry 命名的
什么意思？简单来说，柯里化是一项技术，它用来改造多参数的函数。比如：
```javascript
// 这是一个接受3个参数的函数
const add = function(x, y, z) {
  return x + y + z
}
```
我们将它变换一下，可以得到这样一个函数：
```javascript
// 接收一个单一参数
const curryingAdd = function(x) {
  // 并且返回接受余下的参数的函数
  return function(y, z) {
    return x + y + z
  }
}
```
这样有什么区别呢？从调用上来对比：
```javascript
// 调用add
add(1, 2, 3)

// 调用curryingAdd
curryingAdd(1)(2, 3)
// 看得更清楚一点，等价于下面
const fn = curryingAdd(1)
fn(2, 3)
```
可以看到，变换后的的函数可以分批次接受参数，先记住这一点，下面会讲用处。甚至fn（curryingAdd返回的函数）还可以继续变换：
```javascript
const curryingAdd = function(x) {
  return function(y) {
    return function(z) {
      return x + y + z
    }
  }
}
```
// 调用
```javascript
curryingAdd(1)(2)(3)
// 即
const fn = curryingAdd(1)
const fn1 = fn(2)
fn1(3)
```
上面的两次变换过程，就是函数柯里化
### 函数复用
若是项目的组件中有多处地方采用同一种方式进行处理，例如处理如期格式化，校验规则，文件上传之类我们可以将这些复用较高的代码进行抽象
### 具体实现
我们可以在 src/utils 文件夹下收集这种可以重复使用的函数。根据其性质或者功能点进行归类，总结出自己的工具库
这是对后续项目大有帮助的
对已有公用组件的一些说明
### 列表页面函数集合组件
mixins/page.js
对列表页面的查询和加载，分页进行了一定程度的封装
在页面中通过
```javascript
import page from '@/mixins/page'
export default {
  ...
  mixins: [page],
  ...
  }
```
#### 参数说明
```javascript
      listUrl: '', 
       //列表接口地址 
      queryParams: {
      //接口所需参数
        pageNum: 1,
         //当前的页数
        pageSize: 10
        //分页的页数
      },
      tableId: false,
      loading: false,
      //是否显示加载
      showSearch: true,
      // 显示搜索条件   
      refreshTable: true,
      // 重新渲染表格状态
      tableData: [],     
      // 返回数据
        total: 0
      // 返回数据总条数
```
#### 方法介绍
```javascript
    // 重制参数
    resetQuery() {
    },
    //根据参数加载
    handleQuery() {
    },
    //加载数据
    loadData() {
    }

```
### 根据resful 规范衍生的对单一数据增删改查组件

在页面中调用
```javascript
    data() {
        return {
           ...
           model: this.$modelDataSource({
                url: '/system/enterprise',//接口根地址
                dataKey: 'model',
                attributes: { //你需要获取的参数
                id: '' 
                }
            })
           ... 
        }
    }

```
```javascript
this.model.reset() //重置
this.model.fetch(  // 根据id获取单条数据
        newValue,
        {}, //其他参数
        (success) => {  //成功回调
        },
        (err) => { //失败回调
        }
      )
// 根据id删除数据
      this.model.uuid = id
        this.model.destroy(() => { //成功回调
        this.refreshList = true
        this.$message.success('删除成功')
      })
```