# 车联网安全检测平台 API V202403

## 目录
- [快速开始](#_quick_start)
- [使用指引](#_instruction)
- [操作列表](#_operations)
  - 检测项目
    - [新建文件检测项目](#NewFileTestProject)
    - [新建终端检测项目](#NewClientTestProject)
    - [快速新建检测项目](#FastTestProject)
    - [查询操作系统列表](#GetSystemList)
    - [查询检测终端列表](#GetClientList)
    - [查询安卓设备列表](#GetAndroidDeviceList)
    - [检测设备状态](#DetectDevice)
    - [开始检测](#StartProject)
    - [停止检测](#StopProject)
    - [重置项目](#ResetProject)
    - [删除项目](#DeleteProject)
    - [查询项目列表](#GetProjectList)
    - [查询项目详情](#GetProjectDetail)
    - [查询项目用例列表](#GetProjectCaseList)
    - [查询项目用例详情](#GetProjectCaseDetail)
    - [保存项目用例步骤结果](#SaveProjectCaseStepResult)
    - [查询项目插件步骤结果](#GetProjectPluginStepResult)
    - [查询项目安全审计步骤结果](#GetProjectBaselineStepResult)
    - [查询项目自动化用例步骤结果](#GetProjectAutoStepResult)
  - 测试用例
    - [查询用例属性字典](#GetCaseDictionary)
    - [查询自动化步骤配置字典](#GetAutoStepConfigDictionary)
    - [查询法规属性字典](#GetLawDictionary)
    - [查询法规分类属性字典](#GetLawClassDictionary)
    - [新建用例草稿](#CreateCaseDraft)
    - [保存用例草稿步骤](#SaveCaseDraftStep)
    - [删除用例草稿](#DeleteCaseDraft)
    - [查询用例草稿列表](#GetCaseDraftList)
    - [发布用例](#ReleaseCaseDraft)
    - [查询用例详情](#GetCaseDetail)
    - [查询用例列表](#GetCaseList)
    - [查询用例步骤详情](#GetCaseStepDetail)
    - [查询用例集列表](#GetSuiteList)
  - 其他
    - [查询文件列表](#GetFileList)
    - [查询脚本文件列表](#GetScriptFileList)
    - [查询用户列表](#GetUserList)
- [通用类型](#_common_types)
  - [输入类型](#_input)
    - [RelLawInfo](#RelLawInfo)
    - [StepDraftMetadataInput](#StepDraftMetadataInput)
    - [ButtonInput](#ButtonInput)
    - [KeywordInput](#KeywordInput)
    - [ScriptFileInput](#ScriptFileInput)
    - [AnalysisReportMapInput](#AnalysisReportMapInput)
  - [枚举类型](#_enum)
    - [StepNodeType](#StepNodeType)
    - [ButtonTarget](#ButtonTarget)
    - [KeywordType](#KeywordType)
    - [CommonStatus](#CommonStatus)
  - [标量类型](#_scalar)
    - [Time](#Time)
    - [Map](#Map)
  - [联合类型](#_union)
    - [StepPluginResult](#StepPluginResult)
- [错误码](#error_code)
- [示例脚本](#example)
- [更新日志](#changelog)
## <a id="_quick_start"></a>快速开始

该文档假设你已经熟悉了HTTP协议，了解JSON格式。

安全检测平台提供GraphQL API，如果想了解GraphQL，可以阅读[GraphQL官方文档](https://graphql.cn/learn/)。

如果不想了解GraphQL的语法，也可以将GraphQL查询语句当成普通的字符串输入，参考以下curl样例即可。

### 使用 curl 请求

GraphQL的请求方式有很多种，这里介绍一种简单的方式，使用curl命令请求GraphQL服务。

这里假设GraphQL服务的地址为 `http://vvmp.com/query`(一般情况下路径为query)。请根据实际情况修改域名。

#### 请求格式

```bash
curl -X POST \
    -H "Content-Type: application/json" \
    -H "Content-Type: Bearer <APIToken>" \
    -d '{
            "query": "<查询语句>",
            "variables": {}
        }' \
    http://vvmp.com/query
```

每个GraphQL查询其实是对一个固定URL的POST请求，请求体是JSON格式，其中包含了GraphQL的查询语句和请求参数。

上面的请求中，`query` 是GraphQL的查询语句（每个操作都会提供查询语句，只需填入即可，通常情况下无需修改其内容）。而 `variables` 是GraphQL的请求参数，可以根据实际情况调整参数值。

请注意：查询语句是一个字符串，而请求参数是一个JSON对象。

#### 请求示例：

```bash
curl -X POST \
    -H "Content-Type: application/json" \
    -d '{
            "query": "query info {info}"
        }' \
    http://vvmp.com/query
```

### 获取API Token

如果直接进行上述请求会发现接口返回了errors，具体的错误码是`error-token-invalid`：
```json
{
    "errors": [
        {
            "message": "error-token-invalid",
            "path": [
                "info"
            ],
            "extensions": {
                "params": null,
                "type": "Code"
            }
        }
    ],
    "data": {
        "info": null
    }
}
```
这是因为请求中没有提供Token。可以通过下面步骤创建API Token。

#### 获取登录Token

创建API Token之前需要获取登录Token。

可通过以下命令获取，其中 `query` 字段是一个登录的GraphQL语句，`variables` 字段是登录的请求参数，包括用户名和密码(即`<username>`和`<password>`)，请根据实际情况进行填写。

```bash
curl -X POST \
    -H "Content-Type: application/json" \
    -d '{
            "query": "mutation Login($username: String!, $password: String!) {loginByPassword(input: {username: $username, password: $password}) {token}}",
            "variables": {"username": "<username>", "password": "<password>"}
        }' \
    http://vvmp.com/query
```

示例返回值如下：

```json
{
    "data": {
        "loginByPassword": {
            "token": "<LoginToken>"
        }
    }
}
```

返回值中的 `token` 字段即为登录Token。

#### 创建API Token

通过以下命令创建API Token，注意需要将上一步获取的LoginToken填入请求头中的Authorization字段中。

```bash
curl -X POST \
    -H "Content-Type: application/json" \
    -H "Authorization: Bearer <LoginToken>" \
    -d '{
            "query": "mutation createAPIToken($input: CreateTokenInput!) { token{ createToken(input:$input){ token } } }",
            "variables": {
                "input": {
                    "description": ""
                }
            }
        }' \
    http://vvmp.com/query
```

示例返回值如下：

```json
{
    "data": {
        "token": {
            "createToken": {
                "token": "<APIToken>"
            }
        }
    }
}
```

## <a id="_instruction"></a>使用指引

### 检测项目

当前平台的检测项目，根据检测方式的不同可以分为两种：文件检测和终端检测。前者用于简单场景下的文件分析，无需连接检测终端。后者则是通过检测终端([查询终端列表](#GetClientList))辅助进行用例检测。

创建**终端检测**项目时需要选择指定的操作系统。如果操作系统为android类型，则需要终端连接安卓设备([查询安卓设备列表](#GetAndroidDeviceList))，如果是linux类型，则需要终端连接linux设备。前者需要在终端侧准备完成(adb连接)，后者可直接在平台上输入SSH配置进行连接以获取设备id([获取设备id](#DetectDevice))。

### 测试用例

测试用例分为三种类型：手工、半自动和自动。每个用例都会包括一个或多个步骤(即节点)。步骤也分为三种[类型](#StepNodeType)：手工操作、工具执行、自动化检测报告。其中工具执行节点可以填入脚本、依靠检测终端进行执行。自动化检测报告节点依靠系统集成的三方工具，工具检测完成后系统会获取到对应的检测报告。

半自动类型的测试用例一般同时包括自动和手工的步骤，其中自动步骤自动执行，手工步骤判断执行结果。

新建测试用例一般包括以下步骤：

* [新建用例草稿](#CreateCaseDraft)
* [向用例草稿添加步骤](#SaveCaseDraftStep)
* [发布用例草稿](#ReleaseCaseDraft)

## <a id="_operations"></a>操作列表

### <a id="NewFileTestProject"></a>新建文件检测项目

创建新的检测项目，检测方式为文件检测

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| name | String! | 是 | 项目名称 |
| lawId | String! | 是 | 用例集id，示例："law_items;1"，可参考[查询用例集列表](#GetSuiteList)中返回的id |
| principalUserId | String! | 是 | 负责人id，示例："user_items;1"，可参考[查询用户列表](#GetUserList)中返回的id |
| systemId | String! | 是 | 系统id，示例："system;123"，可参考[查询操作系统列表](#GetSystemList)中返回的systemId |
| fileList | [ID!]! | 是 | 待检测文件列表，示例：["file_management_items;1","file_management_items;2"]，可参考[查询文件列表](#GetFileList)中返回的id |

#### 响应类型

##### <a id="NewFileTestProject_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| projectMutation | [TeamProjectMutation!](#NewFileTestProject_TeamProjectMutation) | 修改检测项目 |

##### <a id="NewFileTestProject_TeamProjectMutation"></a>TeamProjectMutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| project | [Project](#NewFileTestProject_Project) | 创建检测项目 |

##### <a id="NewFileTestProject_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |
| name | String! | 项目名称 |
| description | String! | 项目的描述信息 |
| status | [CommonStatus!](#CommonStatus) | 项目的检测状态，对应未检测、检测中、已完成 |


#### 查询JSON

```json
{
  "query": "fragment ProjectBasicObject on Project{id name description status}mutation NewFileTestProject($name:String!$lawId:ID!$principalUserId:ID!$systemId:ID!$fileList:[ID!]!){projectMutation:teamProject(id:\"team_items;1\"){project:createProject(input:{testMethod:File name:$name lawId:$lawId principalUserId:$principalUserId systemId:$systemId fileList:$fileList}){...ProjectBasicObject}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "projectMutation": {
            "project": {
                "id": "project_items;1",
                "name": "创建样例",
                "description": "",
                "status": "Ready"
            }
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
fragment ProjectBasicObject on Project {
  id
  name
  description
  status
}

mutation NewFileTestProject($name: String!, $lawId: ID!, $principalUserId: ID!, $systemId: ID!, $fileList: [ID!]!) {
  projectMutation: teamProject(id: &quot;team_items;1&quot;) {
    project: createProject(
      input: {testMethod: File, name: $name, lawId: $lawId, principalUserId: $principalUserId, systemId: $systemId, fileList: $fileList}
    ) {
      ...ProjectBasicObject
    }
  }
}
</code></pre>
</details>

### <a id="NewClientTestProject"></a>新建终端检测项目

创建新的检测项目，检测方式为终端检测

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| name | String! | 是 | 项目名称 |
| lawId | String! | 是 | 用例集id，示例："law_items;1"，可参考[查询用例集列表](#GetSuiteList)中返回的id |
| principalUserId | String! | 是 | 负责人id，示例："user_items;1"，可参考[查询用户列表](#GetUserList)中返回的id |
| systemId | String! | 是 | 系统id，示例："system;123"，可参考[查询操作系统列表](#GetSystemList)中返回的systemTypeId |
| clientId | String! | 是 | 终端id，示例："fffff40e-80cc-45f2-9186-fdae87ca327d"，可参考[检测设备状态](#DetectDevice)接口中返回的clientId |
| deviceId | String! | 是 | 设备id，示例："LX-60C1FFFF"，可参考[检测设备状态](#DetectDevice)接口中返回的deviceId |
| connectType | String! | 是 | 连接方式，可选值：pwd或cert，分别表示密码和证书 |
| ip | String! | 是 | 目标设备的IP地址 |
| port | Int! | 是 | 目标设备的端口号 |
| username | String! | 是 | 目标设备的用户名 |
| password | String | 否 | 目标设备的密码 |
| certUrl | String | 否 | 目标设备的证书文件下载地址 |

#### 响应类型

##### <a id="NewClientTestProject_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| projectMutation | [TeamProjectMutation!](#NewClientTestProject_TeamProjectMutation) | 修改检测项目 |

##### <a id="NewClientTestProject_TeamProjectMutation"></a>TeamProjectMutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| project | [Project](#NewClientTestProject_Project) | 创建检测项目 |

##### <a id="NewClientTestProject_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |
| name | String! | 项目名称 |
| description | String! | 项目的描述信息 |
| status | [CommonStatus!](#CommonStatus) | 项目的检测状态，对应未检测、检测中、已完成 |


#### 查询JSON

```json
{
  "query": "fragment ProjectBasicObject on Project{id name description status}mutation NewClientTestProject($name:String!$lawId:ID!$principalUserId:ID!$systemId:ID!$clientId:String!$deviceId:String!$connectType:String!$ip:String!$port:Int!$username:String!$password:String$certUrl:String){projectMutation:teamProject(id:\"team_items;1\"){project:createProject(input:{testMethod:Client name:$name lawId:$lawId principalUserId:$principalUserId systemId:$systemId clientId:$clientId deviceId:$deviceId linuxConnectType:$connectType linuxConnectIP:$ip linuxConnectPort:$port linuxConnectUser:$username linuxConnectPassword:$password linuxConnectCertificateUrl:$certUrl}){...ProjectBasicObject}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "projectMutation": {
            "project": {
                "id": "project_items;1",
                "name": "ExampleProject",
                "description": "",
                "status": "Ready"
            }
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
fragment ProjectBasicObject on Project {
  id
  name
  description
  status
}

mutation NewClientTestProject($name: String!, $lawId: ID!, $principalUserId: ID!, $systemId: ID!, $clientId: String!, $deviceId: String!, $connectType: String!, $ip: String!, $port: Int!, $username: String!, $password: String, $certUrl: String) {
  projectMutation: teamProject(id: &quot;team_items;1&quot;) {
    project: createProject(
      input: {testMethod: Client, name: $name, lawId: $lawId, principalUserId: $principalUserId, systemId: $systemId, clientId: $clientId, deviceId: $deviceId, linuxConnectType: $connectType, linuxConnectIP: $ip, linuxConnectPort: $port, linuxConnectUser: $username, linuxConnectPassword: $password, linuxConnectCertificateUrl: $certUrl}
    ) {
      ...ProjectBasicObject
    }
  }
}
</code></pre>
</details>

### <a id="FastTestProject"></a>快速新建检测项目

快速创建新的检测项目，无需输入用例集，系统将会自动根据输入的用例id列表生成(虚拟)用例集

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| name | String! | 是 | 项目名称 |
| principalUserId | String! | 是 | 负责人id，示例："user_items;1"，可参考[查询用户列表](#GetUserList)中返回的id |
| systemId | String! | 是 | 系统id，示例："system;123"，可参考[查询操作系统列表](#GetSystemList)中返回的systemId |
| caseIdList | [ID!]! | 是 | 用例id列表，示例：["case_items;1","case_items;2"]，可参考[查询用例列表](#GetAllCaseList)中返回的id |
| fileList | [ID!]! | 是 | 待检测文件列表，示例：["file_management_items;1","file_management_items;2"]，可参考[查询文件列表](#GetFileList)中返回的id |

#### 响应类型

##### <a id="FastTestProject_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| projectMutation | [TeamProjectMutation!](#FastTestProject_TeamProjectMutation) | 修改检测项目 |

##### <a id="FastTestProject_TeamProjectMutation"></a>TeamProjectMutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| project | [Project](#FastTestProject_Project) | 创建检测项目 |

##### <a id="FastTestProject_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |
| name | String! | 项目名称 |
| description | String! | 项目的描述信息 |
| status | [CommonStatus!](#CommonStatus) | 项目的检测状态，对应未检测、检测中、已完成 |


#### 查询JSON

```json
{
  "query": "fragment ProjectBasicObject on Project{id name description status}mutation FastTestProject($name:String!$principalUserId:ID!$systemId:ID!$caseIdList:[ID!]!$fileList:[ID!]!){projectMutation:teamProject(id:\"team_items;1\"){project:createProject(input:{testMethod:File name:$name caseIdList:$caseIdList principalUserId:$principalUserId systemId:$systemId fileList:$fileList}){...ProjectBasicObject}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "projectMutation": {
            "project": {
                "id": "project_items;1",
                "name": "创建样例",
                "description": "",
                "status": "Ready"
            }
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
fragment ProjectBasicObject on Project {
  id
  name
  description
  status
}

mutation FastTestProject($name: String!, $principalUserId: ID!, $systemId: ID!, $caseIdList: [ID!]!, $fileList: [ID!]!) {
  projectMutation: teamProject(id: &quot;team_items;1&quot;) {
    project: createProject(
      input: {testMethod: File, name: $name, caseIdList: $caseIdList, principalUserId: $principalUserId, systemId: $systemId, fileList: $fileList}
    ) {
      ...ProjectBasicObject
    }
  }
}
</code></pre>
</details>

### <a id="GetSystemList"></a>查询操作系统列表

查询操作系统列表

#### 请求参数

这个操作不需要参数

#### 响应类型

##### <a id="GetSystemList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| list | [ProjectSelectorList](#GetSystemList_ProjectSelectorList) | 创建项目中。拉取选项菜单 |

##### <a id="GetSystemList_ProjectSelectorList"></a>ProjectSelectorList

| 名称 | 类型 |
| ---- | ---- |
| systemGroup | [[ProjectTestObjectList]!](#GetSystemList_ProjectTestObjectList) |

##### <a id="GetSystemList_ProjectTestObjectList"></a>ProjectTestObjectList

| 名称 | 类型 |
| ---- | ---- |
| systemTypeId | String! |
| systemTypeName | String! |
| systemList | [[ProjectTestObjectSystemList]!](#GetSystemList_ProjectTestObjectSystemList) |

##### <a id="GetSystemList_ProjectTestObjectSystemList"></a>ProjectTestObjectSystemList

| 名称 | 类型 |
| ---- | ---- |
| systemId | String! |
| systemName | String! |
| systemVersion | String |
| hasFile | Boolean! |


#### 查询JSON

```json
{
  "query": "query GetSystemList{list:projectSelectorList(teamId:\"team_items;1\"){systemGroup:testObject{systemTypeId:autoPartsId systemTypeName:autoPartsName systemList:systemChild{systemId systemName systemVersion hasFile:hasFileUrl}}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "list": {
            "systemGroup": [
                {
                    "systemTypeId": "autoParts;1",
                    "systemTypeName": "Linux",
                    "systemList": [
                        {
                            "systemId": "system;1",
                            "systemName": "ExampleOS",
                            "systemVersion": "5.5",
                            "hasFile": false
                        }
                    ]
                }
            ]
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetSystemList {
  list: projectSelectorList(teamId: &quot;team_items;1&quot;) {
    systemGroup: testObject {
      systemTypeId: autoPartsId
      systemTypeName: autoPartsName
      systemList: systemChild {
        systemId
        systemName
        systemVersion
        hasFile: hasFileUrl
      }
    }
  }
}
</code></pre>
</details>

### <a id="GetClientList"></a>查询检测终端列表

查询检测终端列表

#### 请求参数

这个操作不需要参数

#### 响应类型

##### <a id="GetClientList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| result | [ProjectSelectorList](#GetClientList_ProjectSelectorList) | 创建项目中。拉取选项菜单 |

##### <a id="GetClientList_ProjectSelectorList"></a>ProjectSelectorList

| 名称 | 类型 |
| ---- | ---- |
| clientWithDeviceList | [[ProjectClientList]!](#GetClientList_ProjectClientList) |

##### <a id="GetClientList_ProjectClientList"></a>ProjectClientList

| 名称 | 类型 |
| ---- | ---- |
| clientId | String! |
| clientName | String! |
| deviceList | [[ProjectClientDeviceList]!](#GetClientList_ProjectClientDeviceList) |

##### <a id="GetClientList_ProjectClientDeviceList"></a>ProjectClientDeviceList

| 名称 | 类型 |
| ---- | ---- |
| deviceId | String! |
| deviceName | String! |
| isUsable | Boolean! |


#### 查询JSON

```json
{
  "query": "query GetClientList{result:projectSelectorList(teamId:\"team_items;1\"){clientWithDeviceList:clientLinux{clientId clientName deviceList:clientChild{deviceId deviceName isUsable}}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "result": {
            "clientWithDeviceList": [
                {
                    "clientId": "ffffd3e0-aef4-48e0-af38-5ab1585875af",
                    "clientName": "测试终端(Example-Host-0)",
                    "deviceList": []
                },
                {
                    "clientId": "b54ff40e-80cc-45f2-9186-fdae87caffff",
                    "clientName": "测试终端(VM-centos)",
                    "deviceList": []
                }
            ]
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetClientList {
  result: projectSelectorList(teamId: &quot;team_items;1&quot;) {
    clientWithDeviceList: clientLinux {
      clientId
      clientName
      deviceList: clientChild {
        deviceId
        deviceName
        isUsable
      }
    }
  }
}
</code></pre>
</details>

### <a id="GetAndroidDeviceList"></a>查询安卓设备列表

查询连接了安卓设备的终端列表

#### 请求参数

这个操作不需要参数

#### 响应类型

##### <a id="GetAndroidDeviceList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| result | [ProjectSelectorList](#GetAndroidDeviceList_ProjectSelectorList) | 创建项目中。拉取选项菜单 |

##### <a id="GetAndroidDeviceList_ProjectSelectorList"></a>ProjectSelectorList

| 名称 | 类型 |
| ---- | ---- |
| clientWithDeviceList | [[ProjectClientList]!](#GetAndroidDeviceList_ProjectClientList) |

##### <a id="GetAndroidDeviceList_ProjectClientList"></a>ProjectClientList

| 名称 | 类型 |
| ---- | ---- |
| clientId | String! |
| clientName | String! |
| deviceList | [[ProjectClientDeviceList]!](#GetAndroidDeviceList_ProjectClientDeviceList) |

##### <a id="GetAndroidDeviceList_ProjectClientDeviceList"></a>ProjectClientDeviceList

| 名称 | 类型 |
| ---- | ---- |
| deviceId | String! |
| deviceName | String! |
| isUsable | Boolean! |


#### 查询JSON

```json
{
  "query": "query GetAndroidDeviceList{result:projectSelectorList(teamId:\"team_items;1\"){clientWithDeviceList:clientAndroid{clientId clientName deviceList:clientChild{deviceId deviceName isUsable}}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "result": {
            "clientWithDeviceList": [
                {
                    "clientId": "ffffd3e0-aef4-48e0-af38-5ab1585875af",
                    "clientName": "测试终端(Example-Host-0)",
                    "deviceList": [
                        {
                            "deviceId": "ffd332f6",
                            "deviceName": "example",
                            "isUsable": false
                        }
                    ]
                }
            ]
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetAndroidDeviceList {
  result: projectSelectorList(teamId: &quot;team_items;1&quot;) {
    clientWithDeviceList: clientAndroid {
      clientId
      clientName
      deviceList: clientChild {
        deviceId
        deviceName
        isUsable
      }
    }
  }
}
</code></pre>
</details>

### <a id="DetectDevice"></a>检测设备状态

检测设备能否通过输入的ssh配置连接成功，如果连接成功则返回对应的设备id

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| clientId | String! | 是 | 检测终端id，可参考[查询终端列表](#GetClientList)返回中的clientId |
| connectType | String! | 是 | 连接目标设备的方式，可选值：pwd或cert，分别表示密码和证书 |
| ip | String! | 是 | 目标设备的IP地址 |
| port | Int! | 是 | 目标设备的端口号 |
| username | String! | 是 | 目标设备的用户名 |
| password | String | 否 | 目标设备的密码，如果connectType为pwd，则必须填写 |
| certUrl | String | 否 | 目标设备的证书文件下载地址，如果connectType为cert，则必须填写 |

#### 响应类型

##### <a id="DetectDevice_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| checkDeviceOnline | [ClientDeviceOnline](#DetectDevice_ClientDeviceOnline) | 查看设备是否在线 |

##### <a id="DetectDevice_ClientDeviceOnline"></a>ClientDeviceOnline

| 名称 | 类型 |
| ---- | ---- |
| isOnline | Boolean! |
| deviceType | String! |
| deviceId | String! |
| deviceName | String! |
| clientId | String! |


#### 查询JSON

```json
{
  "query": "query DetectDevice($clientId:String!$connectType:String!$ip:String!$port:Int!$username:String!$password:String$certUrl:String){checkDeviceOnline(teamId:\"team_items;1\" clientId:$clientId connectType:$connectType connectIP:$ip connectPort:$port connectUser:$username connectPassword:$password connectCertificateUrl:$certUrl deviceType:\"linux\"){isOnline deviceType deviceId deviceName clientId}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "checkDeviceOnline": {
            "isOnline": true,
            "deviceType": "linux",
            "deviceId": "LX-ff7853B7",
            "deviceName": "TestHost",
            "clientId": "ffffd3e0-aef4-48e0-af38-5ab1585875af"
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query DetectDevice($clientId: String!, $connectType: String!, $ip: String!, $port: Int!, $username: String!, $password: String, $certUrl: String) {
  checkDeviceOnline(
    teamId: &quot;team_items;1&quot;
    clientId: $clientId
    connectType: $connectType
    connectIP: $ip
    connectPort: $port
    connectUser: $username
    connectPassword: $password
    connectCertificateUrl: $certUrl
    deviceType: &quot;linux&quot;
  ) {
    isOnline
    deviceType
    deviceId
    deviceName
    clientId
  }
}
</code></pre>
</details>

### <a id="StartProject"></a>开始检测

开始检测项目

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 项目id，示例："project_items;1" |

#### 响应类型

##### <a id="StartProject_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| project | [Project](#StartProject_Project) | 开始检测 |

##### <a id="StartProject_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |


#### 查询JSON

```json
{
  "query": "mutation StartProject($projectId:ID!){project:startProjectDetection(teamId:\"team_items;1\" projectId:$projectId){id}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "project": {
            "id": "project_items;1"
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation StartProject($projectId: ID!) {
  project: startProjectDetection(teamId: &quot;team_items;1&quot;, projectId: $projectId) {
    id
  }
}
</code></pre>
</details>

### <a id="StopProject"></a>停止检测

停止检测项目

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 项目id，示例："project_items;1" |

#### 响应类型

##### <a id="StopProject_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| project | [Project](#StopProject_Project) | 结束项目 |

##### <a id="StopProject_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |


#### 查询JSON

```json
{
  "query": "mutation StopProject($projectId:ID!){project:stopProject(teamId:\"team_items;1\" projectId:$projectId){id}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "project": {
            "id": "project_items;1"
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation StopProject($projectId: ID!) {
  project: stopProject(teamId: &quot;team_items;1&quot;, projectId: $projectId) {
    id
  }
}
</code></pre>
</details>

### <a id="ResetProject"></a>重置项目

重置检测项目，重新开始检测

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 项目id，示例："project_items;1" |

#### 响应类型

##### <a id="ResetProject_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| project | [Project](#ResetProject_Project) | 重置项目 |

##### <a id="ResetProject_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |


#### 查询JSON

```json
{
  "query": "mutation ResetProject($projectId:ID!){project:resetProject(teamId:\"team_items;1\" projectId:$projectId){id}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "project": {
            "id": "project_items;1"
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation ResetProject($projectId: ID!) {
  project: resetProject(teamId: &quot;team_items;1&quot;, projectId: $projectId) {
    id
  }
}
</code></pre>
</details>

### <a id="DeleteProject"></a>删除项目

删除检测项目，支持批量

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectIdList | [ID!]! | 是 | 项目id列表，示例：["project_items;1","project_items;2"] |

#### 响应类型

##### <a id="DeleteProject_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| projectMutation | [TeamProjectMutation!](#DeleteProject_TeamProjectMutation) | 修改检测项目 |

##### <a id="DeleteProject_TeamProjectMutation"></a>TeamProjectMutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| projectList | [[Project]](#DeleteProject_Project) | 删除检测项目，支持批量，输入为项目ID列表 |

##### <a id="DeleteProject_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |


#### 查询JSON

```json
{
  "query": "mutation DeleteProject($projectIdList:[ID!]!){projectMutation:teamProject(id:\"team_items;1\"){projectList:deleteProject(input:$projectIdList){id}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation DeleteProject($projectIdList: [ID!]!) {
  projectMutation: teamProject(id: &quot;team_items;1&quot;) {
    projectList: deleteProject(input: $projectIdList) {
      id
    }
  }
}
</code></pre>
</details>

### <a id="GetProjectList"></a>查询项目列表

查询检测项目列表

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| offset | Int | 否 | 分页参数，偏移量，默认为0 |
| limit | Int | 否 | 分页参数，返回个数，默认为20 |
| name | String | 否 | 搜索参数，用于匹配检测项目名称 |

#### 响应类型

##### <a id="GetProjectList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| projectList | [ProjectInfoRsp](#GetProjectList_ProjectInfoRsp) | 查询检测项目列表 |

##### <a id="GetProjectList_ProjectInfoRsp"></a>ProjectInfoRsp

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| count | Int | 项目数量 |
| list | [[ProjectInfo]](#GetProjectList_ProjectInfo) | 项目信息列表 |

##### <a id="GetProjectList_ProjectInfo"></a>ProjectInfo

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |
| name | String! | 项目名称 |
| submitTime | String! | 项目的提交时间 |
| dutyUserName | String! | 责任人名称 |
| taskStatus | Int! |  |
| caseSuiteName | String! | 用例集名称 |
| caseCount | Int! | 用例数量 |
| systemType | String | 系统类型 |
| systemName | String | 系统名称 |
| systemVersion | String | 系统版本 |


#### 查询JSON

```json
{
  "query": "fragment ProjectListObject on ProjectInfo{id name submitTime dutyUserName:dutyUser taskStatus caseSuiteName:lawStandard caseCount:caseNumber systemType systemName systemVersion}query GetProjectList($offset:Int=0$limit:Int=20$name:String){projectList(teamId:\"team_items;1\" search:{offset:{offset:$offset limit:$limit}searchField:\"name\" search:$name}){count list:projectInfo{...ProjectListObject}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
fragment ProjectListObject on ProjectInfo {
  id
  name
  submitTime
  dutyUserName: dutyUser
  taskStatus
  caseSuiteName: lawStandard
  caseCount: caseNumber
  systemType
  systemName
  systemVersion
}

query GetProjectList($offset: Int = 0, $limit: Int = 20, $name: String) {
  projectList(
    teamId: &quot;team_items;1&quot;
    search: {offset: {offset: $offset, limit: $limit}, searchField: &quot;name&quot;, search: $name}
  ) {
    count
    list: projectInfo {
      ...ProjectListObject
    }
  }
}
</code></pre>
</details>

### <a id="GetProjectDetail"></a>查询项目详情

查询单个检测项目详情

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 项目id，示例："project_items;1" |

#### 响应类型

##### <a id="GetProjectDetail_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| project | [Node](#GetProjectDetail_Project) | 根据ID查询对象 |
| projectDetails | [ProjectDetailsRsp](#GetProjectDetail_ProjectDetailsRsp) | 项目详情 |
| complianceResult | [CatalogueTestResultRsp](#GetProjectDetail_CatalogueTestResultRsp) | 合规维度数据统计（合规概览） |

##### <a id="GetProjectDetail_Project"></a>Project

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |
| name | String! | 项目名称 |
| description | String! | 项目的描述信息 |
| status | [CommonStatus!](#CommonStatus) | 项目的检测状态，对应未检测、检测中、已完成 |
| caseResultCount | [ProjectCaseResultCount](#GetProjectDetail_ProjectCaseResultCount) | 项目中检测用例数量信息 |
| files | [[FileManagementItem!]](#GetProjectDetail_FileManagementItem) | 项目的检测文件 |

##### <a id="GetProjectDetail_ProjectCaseResultCount"></a>ProjectCaseResultCount

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| autoCaseCount | Int! | 自动化测试用例数量 |
| semiAutomaticCaseCount | Int! | 半自动化测试用例数量 |
| manualCaseCount | Int! | 手动测试用例数量 |
| ignoreCaseCount | Int | 自动忽略的测试用例数量 |

##### <a id="GetProjectDetail_FileManagementItem"></a>FileManagementItem

| 名称 | 类型 |
| ---- | ---- |
| ID | String! |
| name | String! |

##### <a id="GetProjectDetail_ProjectDetailsRsp"></a>ProjectDetailsRsp

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| projectResult | [ProjectInfo](#GetProjectDetail_ProjectInfo) | 项目信息 |

##### <a id="GetProjectDetail_ProjectInfo"></a>ProjectInfo

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! | 项目ID，示例："project_items;1" |
| name | String! | 项目名称 |
| submitTime | String! | 项目的提交时间 |
| dutyUserName | String! | 责任人名称 |
| taskStatus | Int! |  |
| caseSuiteName | String! | 用例集名称 |
| caseCount | Int! | 用例数量 |
| systemType | String | 系统类型 |
| systemName | String | 系统名称 |
| systemVersion | String | 系统版本 |
| testResult | [ProjectTestResultRsp](#GetProjectDetail_ProjectTestResultRsp) |  |
| testDeviceId | String |  |
| testObject | [ProjectTestObjectInfo](#GetProjectDetail_ProjectTestObjectInfo) |  |

##### <a id="GetProjectDetail_ProjectTestResultRsp"></a>ProjectTestResultRsp

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| passRate | Float | 通过率 |
| passNumber | Int | 通过数量 |
| ignoreNumber | Int | 忽略数量 |
| unPassNumber | Int | 未通过数量 |
| unTestNumber | Int | 未检测数量 |
| caseNumber | Int | 总数 |
| testingNumber | Int | 测试中数量 |

##### <a id="GetProjectDetail_ProjectTestObjectInfo"></a>ProjectTestObjectInfo

| 名称 | 类型 |
| ---- | ---- |
| autoPartsName | String |
| systemName | String |
| systemType | String |
| systemVersion | String |

##### <a id="GetProjectDetail_CatalogueTestResultRsp"></a>CatalogueTestResultRsp

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| passNumber | Int | 通过数量 |
| unPassNumber | Int | 未通过数量 |
| unTestNumber | Int | 未测试数量 |
| ignoreNumber | Int | 忽略数量 |
| passRate | Float | 通过率 |
| catalogueNumber | Int | 总数 |
| testingNumber | Int | 测试中数量 |


#### 查询JSON

```json
{
  "query": "fragment ProjectBasicObject on Project{id name description status}fragment ProjectListObject on ProjectInfo{id name submitTime dutyUserName:dutyUser taskStatus caseSuiteName:lawStandard caseCount:caseNumber systemType systemName systemVersion}fragment ProjectTestResultObject on ProjectTestResultRsp{passRate passNumber ignoreNumber unPassNumber unTestNumber caseNumber testingNumber}fragment ProjectComplianceResultObject on CatalogueTestResultRsp{passNumber unPassNumber unTestNumber ignoreNumber passRate catalogueNumber testingNumber}query GetProjectDetail($projectId:ID!){project:node(id:$projectId){...on Project{...ProjectBasicObject caseResultCount{autoCaseCount semiAutomaticCaseCount manualCaseCount ignoreCaseCount}files{ID name}}}projectDetails(teamId:\"team_items;1\" projectId:$projectId){projectResult{...ProjectListObject testResult{...ProjectTestResultObject}testDeviceId testObject{autoPartsName systemName systemType systemVersion}}}complianceResult(teamId:\"team_items;1\" projectId:$projectId){...ProjectComplianceResultObject}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
fragment ProjectBasicObject on Project {
  id
  name
  description
  status
}

fragment ProjectListObject on ProjectInfo {
  id
  name
  submitTime
  dutyUserName: dutyUser
  taskStatus
  caseSuiteName: lawStandard
  caseCount: caseNumber
  systemType
  systemName
  systemVersion
}

fragment ProjectTestResultObject on ProjectTestResultRsp {
  passRate
  passNumber
  ignoreNumber
  unPassNumber
  unTestNumber
  caseNumber
  testingNumber
}

fragment ProjectComplianceResultObject on CatalogueTestResultRsp {
  passNumber
  unPassNumber
  unTestNumber
  ignoreNumber
  passRate
  catalogueNumber
  testingNumber
}

query GetProjectDetail($projectId: ID!) {
  project: node(id: $projectId) {
    ... on Project {
      ...ProjectBasicObject
      caseResultCount {
        autoCaseCount
        semiAutomaticCaseCount
        manualCaseCount
        ignoreCaseCount
      }
      files {
        ID
        name
      }
    }
  }
  projectDetails(teamId: &quot;team_items;1&quot;, projectId: $projectId) {
    projectResult {
      ...ProjectListObject
      testResult {
        ...ProjectTestResultObject
      }
      testDeviceId
      testObject {
        autoPartsName
        systemName
        systemType
        systemVersion
      }
    }
  }
  complianceResult(teamId: &quot;team_items;1&quot;, projectId: $projectId) {
    ...ProjectComplianceResultObject
  }
}
</code></pre>
</details>

### <a id="GetProjectCaseList"></a>查询项目用例列表

查询检测项目用例列表

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 项目id，示例："project_items;1" |
| offset | Int | 否 | 分页参数，表示偏移量，默认为0 |
| limit | Int | 否 | 分页参数，表示返回数量，默认为50 |
| search | String | 否 | 搜索参数，用于匹配用例名称 |

#### 响应类型

##### <a id="GetProjectCaseList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| caseResultList | [CaseResultListRsp](#GetProjectCaseList_CaseResultListRsp) | 用例结果 |

##### <a id="GetProjectCaseList_CaseResultListRsp"></a>CaseResultListRsp

| 名称 | 类型 |
| ---- | ---- |
| count | Int! |
| list | [[CaseResult]!](#GetProjectCaseList_CaseResult) |

##### <a id="GetProjectCaseList_CaseResult"></a>CaseResult

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | Int! | id 前端唯一id |
| caseId | String! |  |
| serialNumber | String |  |
| caseName | String! |  |
| status | Int! | case status |
| handlerUser | String! | handler user name |
| catalogue | String! | catalogue law catalogue name |
| lawCatalogueId | String! | catalogue law catalogue Id |
| classifyName | String | 分类 |
| classifyId | Int |  |
| operatingSystemName | String | 系统 |
| operatingSystemID | Int |  |
| riskLevelName | String | 风险 |
| riskLevelType | String |  |
| riskLevelId | Int |  |
| serialNumber | String |  |
| testMethodName | String | 测试方法 |
| testMethodId | Int |  |
| testMethodType | String |  |
| isBind | Boolean! |  |
| bindName | String! |  |
| handlerId | String! | handler id |
| operatingSystemType | String |  |


#### 查询JSON

```json
{
  "query": "query GetProjectCaseList($projectId:ID!$offset:Int=0$limit:Int=100$search:String){caseResultList(teamId:\"team_items;1\" projectId:$projectId search:{offset:{offset:$offset limit:$limit}search:$search searchField:\"name\"}){count list:caseResultList{id caseId serialNumber caseName status handlerUser catalogue lawCatalogueId classifyName classifyId operatingSystemName operatingSystemID riskLevelName riskLevelType riskLevelId serialNumber testMethodName testMethodId testMethodType:testMothodType isBind bindName handlerId operatingSystemType}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetProjectCaseList($projectId: ID!, $offset: Int = 0, $limit: Int = 100, $search: String) {
  caseResultList(
    teamId: &quot;team_items;1&quot;
    projectId: $projectId
    search: {offset: {offset: $offset, limit: $limit}, search: $search, searchField: &quot;name&quot;}
  ) {
    count
    list: caseResultList {
      id
      caseId
      serialNumber
      caseName
      status
      handlerUser
      catalogue
      lawCatalogueId
      classifyName
      classifyId
      operatingSystemName
      operatingSystemID
      riskLevelName
      riskLevelType
      riskLevelId
      serialNumber
      testMethodName
      testMethodId
      testMethodType: testMothodType
      isBind
      bindName
      handlerId
      operatingSystemType
    }
  }
}
</code></pre>
</details>

### <a id="GetProjectCaseDetail"></a>查询项目用例详情

查询检测项目中某个用例的详细信息，包括步骤列表、当前步骤、用例状态等

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 检测项目ID，示例："project_items;1" |
| caseId | String! | 是 | 用例ID，示例："case_items;1" |

#### 响应类型

##### <a id="GetProjectCaseDetail_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| detail | [GetCaseAllStepRsp](#GetProjectCaseDetail_GetCaseAllStepRsp) | 获得所有模块化步骤支持列表 |

##### <a id="GetProjectCaseDetail_GetCaseAllStepRsp"></a>GetCaseAllStepRsp

| 名称 | 类型 |
| ---- | ---- |
| stepList | [[StepInfo]](#GetProjectCaseDetail_StepInfo) |
| currentStepIndex | Int! |
| caseId | String! |
| caseName | String! |
| caseStatus | Int! |
| hasNexCase | Boolean |
| nextCaseId | String |

##### <a id="GetProjectCaseDetail_StepInfo"></a>StepInfo

| 名称 | 类型 |
| ---- | ---- |
| stepId | String |
| stepName | String |


#### 查询JSON

```json
{
  "query": "query GetProjectCaseDetail($projectId:ID!$caseId:ID!){detail:getCaseAllStep(teamId:\"team_items;1\" caseId:$caseId projectId:$projectId){stepList:stepInfoList{stepId stepName}currentStepIndex:currentCaseStepIndex caseId caseName caseStatus hasNexCase nextCaseId}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "detail": {
            "stepList": [
                {
                    "stepId": "case_step_item;1",
                    "stepName": "节点"
                }
            ],
            "currentStepIndex": 1,
            "caseId": "case_items;1",
            "caseName": "示例用例名称",
            "caseStatus": 2,
            "hasNexCase": true,
            "nextCaseId": "case_items;2"
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetProjectCaseDetail($projectId: ID!, $caseId: ID!) {
  detail: getCaseAllStep(
    teamId: &quot;team_items;1&quot;
    caseId: $caseId
    projectId: $projectId
  ) {
    stepList: stepInfoList {
      stepId
      stepName
    }
    currentStepIndex: currentCaseStepIndex
    caseId
    caseName
    caseStatus
    hasNexCase
    nextCaseId
  }
}
</code></pre>
</details>

### <a id="SaveProjectCaseStepResult"></a>保存项目用例步骤结果

保存检测项目用例步骤结果

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 检测项目ID，示例："project_items;1" |
| caseId | String! | 是 | 用例ID，示例："case_items;1" |
| stepId | String! | 是 | 用例步骤ID，示例："case_step_items;1" |
| stepType | String! | 是 | 步骤类型，可参考[步骤类型枚举](#StepNodeType) |
| buttonName | String! | 是 | 按钮名称，如"通过"，可以参考[查询步骤详情](#GetCaseStepDetail)中返回的metadata.buttons |
| buttonType | String! | 是 | 按钮类型，如"next"，可以参考[查询步骤详情](#GetCaseStepDetail)中返回的metadata.buttons |

#### 响应类型

##### <a id="SaveProjectCaseStepResult_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| success | Boolean! | 新版 保存步骤结果 |


#### 查询JSON

```json
{
  "query": "mutation SaveProjectCaseStepResult($projectId:ID!$caseId:ID!$stepId:ID!$stepType:String!$buttonName:String!$buttonType:String!){success:saveStepInfo(teamId:\"team_items;1\" projectId:$projectId caseId:$caseId stepId:$stepId stepType:$stepType buttonName:$buttonName buttonType:$buttonType)}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "success": true
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation SaveProjectCaseStepResult($projectId: ID!, $caseId: ID!, $stepId: ID!, $stepType: String!, $buttonName: String!, $buttonType: String!) {
  success: saveStepInfo(
    teamId: &quot;team_items;1&quot;
    projectId: $projectId
    caseId: $caseId
    stepId: $stepId
    stepType: $stepType
    buttonName: $buttonName
    buttonType: $buttonType
  )
}
</code></pre>
</details>

### <a id="GetProjectPluginStepResult"></a>查询项目插件步骤结果

查询检测项目中自动化插件步骤的运行结果

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 检测项目ID，示例："project_items;1" |
| caseId | String! | 是 | 用例ID，示例："case_items;1" |
| stepId | String! | 是 | 用例步骤ID，示例："case_step_items;1" |

#### 响应类型

##### <a id="GetProjectPluginStepResult_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| result | [CommonalityAutoTaskReportRep](#GetProjectPluginStepResult_CommonalityAutoTaskReportRep) | 查询自动化检测步骤的具体报告结果 |

##### <a id="GetProjectPluginStepResult_CommonalityAutoTaskReportRep"></a>CommonalityAutoTaskReportRep

| 名称 | 类型 |
| ---- | ---- |
| pluginResult | [StepPluginResult](#StepPluginResult) |

##### <a id="GetProjectPluginStepResult_StepPluginJSONResult"></a>StepPluginJSONResult

| 名称 | 类型 |
| ---- | ---- |

##### <a id="GetProjectPluginStepResult_StepPluginURLResult"></a>StepPluginURLResult

| 名称 | 类型 |
| ---- | ---- |

##### <a id="GetProjectPluginStepResult_StepPluginHTMLResult"></a>StepPluginHTMLResult

| 名称 | 类型 |
| ---- | ---- |


#### 查询JSON

```json
{
  "query": "query GetProjectPluginStepResult($projectId:ID!$caseId:ID!$stepId:ID!){result:getCommonalityAutoTaskReport(teamId:\"team_items;1\" component:null version:null path:null projectId:$projectId caseId:$caseId caseStepId:$stepId search:{offset:{offset:0 limit:-1}}){pluginResult{...on StepPluginJSONResult{json}...on StepPluginURLResult{urlList}...on StepPluginHTMLResult{base64html:html}}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetProjectPluginStepResult($projectId: ID!, $caseId: ID!, $stepId: ID!) {
  result: getCommonalityAutoTaskReport(
    teamId: &quot;team_items;1&quot;
    component: null
    version: null
    path: null
    projectId: $projectId
    caseId: $caseId
    caseStepId: $stepId
    search: {offset: {offset: 0, limit: -1}}
  ) {
    pluginResult {
      ... on StepPluginJSONResult {
        json
      }
      ... on StepPluginURLResult {
        urlList
      }
      ... on StepPluginHTMLResult {
        base64html: html
      }
    }
  }
}
</code></pre>
</details>

### <a id="GetProjectBaselineStepResult"></a>查询项目安全审计步骤结果

查询项目中配置了安全审计规则步骤的运行结果

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 检测项目ID，示例："project_items;1" |
| caseId | String! | 是 | 用例ID，示例："case_items;1" |
| stepId | String! | 是 | 用例步骤ID，示例："case_step_items;1" |

#### 响应类型

##### <a id="GetProjectBaselineStepResult_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| result | [ReportViewActionRsp](#GetProjectBaselineStepResult_ReportViewActionRsp) | 查看报告步骤 查看报告 |

##### <a id="GetProjectBaselineStepResult_ReportViewActionRsp"></a>ReportViewActionRsp

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| count | Int! |  |
| type | String | 报告类型，可能值：PLUGIN;SAFE;CHECK_SEC;CVE;DETAIL_PERMISSION;DETAIL_FILE;DETAIL_LICENSE;DETAIL_APP_CONFIG;OPEN_ASSEMBLY |
| plugin | String | 工具类型，可能值：ApkPecker;SysAuditor;其他具体的三方插件名称 |
| resultList | [[CaseReport]!](#GetProjectBaselineStepResult_CaseReport) | 安全审计结果列表 |

##### <a id="GetProjectBaselineStepResult_CaseReport"></a>CaseReport

| 名称 | 类型 |
| ---- | ---- |
| object | String! |
| sysAnalysisId | String! |
| list | [[SysAuditorReport]](#GetProjectBaselineStepResult_SysAuditorReport) |

##### <a id="GetProjectBaselineStepResult_SysAuditorReport"></a>SysAuditorReport

| 名称 | 类型 |
| ---- | ---- |
| ruleName | String! |
| riskLevel | String! |
| catalog | String! |
| description | String! |
| remediation | String! |
| riskContent | String! |
| riskReason | String! |


#### 查询JSON

```json
{
  "query": "query GetProjectBaselineStepResult($projectId:ID!$caseId:ID!$stepId:ID!){result:reportViewAction(teamId:\"team_items;1\" caseId:$caseId caseStepId:$stepId projectId:$projectId){count type plugin:toolType resultList:caseReportList{object:appName sysAnalysisId list:sysAuditorReportList{ruleName riskLevel catalog description remediation riskContent riskReason}}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetProjectBaselineStepResult($projectId: ID!, $caseId: ID!, $stepId: ID!) {
  result: reportViewAction(
    teamId: &quot;team_items;1&quot;
    caseId: $caseId
    caseStepId: $stepId
    projectId: $projectId
  ) {
    count
    type
    plugin: toolType
    resultList: caseReportList {
      object: appName
      sysAnalysisId
      list: sysAuditorReportList {
        ruleName
        riskLevel
        catalog
        description
        remediation
        riskContent
        riskReason
      }
    }
  }
}
</code></pre>
</details>

### <a id="GetProjectAutoStepResult"></a>查询项目自动化用例步骤结果

查询检测项目自动化用例步骤结果，不包括[基线审计](#GetProjectBaselineStepResult)和[插件](#GetProjectPluginStepResult)结果

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| projectId | String! | 是 | 检测项目id，示例："project_items;1" |
| caseId | String! | 是 | 用例id，示例："case_items;1" |
| stepId | String! | 是 | 用例步骤id：示例："case_step_items;1" |
| offset | Int! | 否 | 分页参数，表示偏移量，默认为0 |
| limit | Int! | 否 | 分页参数，表示返回数量，默认为100 |

#### 响应类型

##### <a id="GetProjectAutoStepResult_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| result | [CommonalityAutoTaskReportRep](#GetProjectAutoStepResult_CommonalityAutoTaskReportRep) | 查询自动化检测步骤的具体报告结果 |

##### <a id="GetProjectAutoStepResult_CommonalityAutoTaskReportRep"></a>CommonalityAutoTaskReportRep

| 名称 | 类型 |
| ---- | ---- |
| count | Int |
| user | [[ReportSystemUser]](#GetProjectAutoStepResult_ReportSystemUser) |
| file | [[ReportFile]](#GetProjectAutoStepResult_ReportFile) |
| CVE | [[ReportCVESec]](#GetProjectAutoStepResult_ReportCVESec) |
| apkSignature | [[ReportApkSignature]](#GetProjectAutoStepResult_ReportApkSignature) |
| apkManifest | [[ReportApkManifest]](#GetProjectAutoStepResult_ReportApkManifest) |
| checkSec | [[ReportCheckSec]](#GetProjectAutoStepResult_ReportCheckSec) |
| apkComponents | [[ComplianceApkComponents]](#GetProjectAutoStepResult_ComplianceApkComponents) |

##### <a id="GetProjectAutoStepResult_ReportSystemUser"></a>ReportSystemUser

| 名称 | 类型 |
| ---- | ---- |
| gid | Int |
| passwordHash | String |
| shell | String |
| uid | Int |
| userName | String |

##### <a id="GetProjectAutoStepResult_ReportFile"></a>ReportFile

| 名称 | 类型 |
| ---- | ---- |
| name | String |
| perm | String |
| type | String |

##### <a id="GetProjectAutoStepResult_ReportCVESec"></a>ReportCVESec

| 名称 | 类型 |
| ---- | ---- |
| component | String |
| risk | [[ReportCVESecRisk]](#GetProjectAutoStepResult_ReportCVESecRisk) |
| version | String |
| cvss | Float |
| cvssRank | String |
| name | String |
| patch | String |
| poc | String |
| status | String |
| exp | String |

##### <a id="GetProjectAutoStepResult_ReportCVESecRisk"></a>ReportCVESecRisk

| 名称 | 类型 |
| ---- | ---- |
| count | Int |
| risk | String |

##### <a id="GetProjectAutoStepResult_ReportApkSignature"></a>ReportApkSignature

| 名称 | 类型 |
| ---- | ---- |
| appName | String |
| algorithm | String |
| from | String |
| oid | String |
| subject | String |
| to | String |
| version | String |

##### <a id="GetProjectAutoStepResult_ReportApkManifest"></a>ReportApkManifest

| 名称 | 类型 |
| ---- | ---- |
| appName | String |
| allowBackup | Boolean |
| debuggable | Boolean |

##### <a id="GetProjectAutoStepResult_ReportCheckSec"></a>ReportCheckSec

| 名称 | 类型 |
| ---- | ---- |
| canary | String |
| name | String |
| nx | String |
| pie | String |
| relro | String |
| rpath | String |
| runpath | String |
| symbols | String |

##### <a id="GetProjectAutoStepResult_ComplianceApkComponents"></a>ComplianceApkComponents

| 名称 | 类型 |
| ---- | ---- |
| appName | String |
| activities | [String] |
| providers | [String] |
| receivers | [String] |
| services | [String] |


#### 查询JSON

```json
{
  "query": "query GetProjectAutoStepResult($projectId:ID!$caseId:ID!$stepId:ID!$offset:Int!=0$limit:Int!=100){result:getCommonalityAutoTaskReport(teamId:\"team_items;1\" component:null version:null path:null projectId:$projectId caseId:$caseId caseStepId:$stepId search:{offset:{offset:$offset limit:$limit}}){count user:reportSystemUser{gid passwordHash shell uid userName}file:reportFile{name perm type}CVE:reportCVESec{component risk{count risk}version cvss cvssRank name patch poc status exp}apkSignature:reportApkSignature{appName algorithm from oid subject to version}apkManifest:reportApkManifest{appName allowBackup debuggable}checkSec:reportCheckSec{canary name nx pie relro rpath runpath symbols}apkComponents:apkComponents{appName activities providers receivers services}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetProjectAutoStepResult($projectId: ID!, $caseId: ID!, $stepId: ID!, $offset: Int! = 0, $limit: Int! = 100) {
  result: getCommonalityAutoTaskReport(
    teamId: &quot;team_items;1&quot;
    component: null
    version: null
    path: null
    projectId: $projectId
    caseId: $caseId
    caseStepId: $stepId
    search: {offset: {offset: $offset, limit: $limit}}
  ) {
    count
    user: reportSystemUser {
      gid
      passwordHash
      shell
      uid
      userName
    }
    file: reportFile {
      name
      perm
      type
    }
    CVE: reportCVESec {
      component
      risk {
        count
        risk
      }
      version
      cvss
      cvssRank
      name
      patch
      poc
      status
      exp
    }
    apkSignature: reportApkSignature {
      appName
      algorithm
      from
      oid
      subject
      to
      version
    }
    apkManifest: reportApkManifest {
      appName
      allowBackup
      debuggable
    }
    checkSec: reportCheckSec {
      canary
      name
      nx
      pie
      relro
      rpath
      runpath
      symbols
    }
    apkComponents: apkComponents {
      appName
      activities
      providers
      receivers
      services
    }
  }
}
</code></pre>
</details>

### <a id="GetCaseDictionary"></a>查询用例属性字典

查询测试用例属性的键值映射，包括绑定设备、用例分类、操作系统类型、风险等级、检测方法、法律法规等

#### 请求参数

这个操作不需要参数

#### 响应类型

##### <a id="GetCaseDictionary_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| dictionary | [CaseCheckedItemV2](#GetCaseDictionary_CaseCheckedItemV2) | 用例生产：下拉列表 |

##### <a id="GetCaseDictionary_CaseCheckedItemV2"></a>CaseCheckedItemV2

| 名称 | 类型 |
| ---- | ---- |
| bindDevice | [[RelLawSelector]](#GetCaseDictionary_RelLawSelector) |
| class | [[RelLawSelector]](#GetCaseDictionary_RelLawSelector) |
| operatingSystem | [[RelLawSelector]](#GetCaseDictionary_RelLawSelector) |
| riskLevel | [[RelLawSelector]](#GetCaseDictionary_RelLawSelector) |
| testMethod | [[RelLawSelector]](#GetCaseDictionary_RelLawSelector) |
| law | [[RelLawSelector]](#GetCaseDictionary_RelLawSelector) |

##### <a id="GetCaseDictionary_RelLawSelector"></a>RelLawSelector

| 名称 | 类型 |
| ---- | ---- |
| value | String |
| label | String |


#### 查询JSON

```json
{
  "query": "query GetCaseDictionary{dictionary:getProductionCaseStaticCheckedItems{bindDevice:bindList{value label}class:classifyList{value label}operatingSystem{value label}riskLevel{value label}testMethod{value label}law{value label}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "options": {
            "bindDevice": [
                {
                    "value": "34",
                    "label": "需要"
                },
                {
                    "value": "35",
                    "label": "不需要"
                }
            ],
            "class": [
                {
                    "value": "4",
                    "label": "操作系统安全"
                },
                {
                    "value": "5",
                    "label": "数据安全"
                },
                {
                    "value": "6",
                    "label": "通信协议与接口安全"
                },
                {
                    "value": "7",
                    "label": "Android APP安全"
                }
            ],
            "operatingSystem": [
                {
                    "value": "18",
                    "label": "Android"
                },
                {
                    "value": "19",
                    "label": "Linux"
                },
                {
                    "value": "20",
                    "label": "通用"
                }
            ],
            "riskLevel": [
                {
                    "value": "28",
                    "label": "高危"
                },
                {
                    "value": "29",
                    "label": "中危"
                },
                {
                    "value": "30",
                    "label": "低危"
                },
                {
                    "value": "36",
                    "label": "N/A"
                }
            ],
            "testMethod": [
                {
                    "value": "31",
                    "label": "手工"
                },
                {
                    "value": "32",
                    "label": "半自动"
                },
                {
                    "value": "33",
                    "label": "自动"
                }
            ],
            "law": [
                {
                    "value": "law_items;1",
                    "label": "车载信息交互系统信息安全技术要求"
                },
                {
                    "value": "law_items;2",
                    "label": "汽车网关信息安全技术要求及试验方法"
                },
                {
                    "value": "law_items;3",
                    "label": "汽车整车信息安全技术要求"
                },
                {
                    "value": "law_items;4",
                    "label": "UN_Regulation_No.155"
                },
                {
                    "value": "law_items;5",
                    "label": "UN_Regulation_No.156"
                }
            ]
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetCaseDictionary {
  dictionary: getProductionCaseStaticCheckedItems {
    bindDevice: bindList {
      value
      label
    }
    class: classifyList {
      value
      label
    }
    operatingSystem {
      value
      label
    }
    riskLevel {
      value
      label
    }
    testMethod {
      value
      label
    }
    law {
      value
      label
    }
  }
}
</code></pre>
</details>

### <a id="GetAutoStepConfigDictionary"></a>查询自动化步骤配置字典

查询自动化步骤配置字典，用于[保存用例草稿步骤](#SaveCaseDraftStep)中步骤配置的AnalysisReportMap

#### 请求参数

这个操作不需要参数

#### 响应类型

##### <a id="GetAutoStepConfigDictionary_Query"></a>Query

| 名称 | 类型 |
| ---- | ---- |
| dictionary | [[AuditorTool!]](#GetAutoStepConfigDictionary_AuditorTool) |

##### <a id="GetAutoStepConfigDictionary_AuditorTool"></a>AuditorTool

| 名称 | 类型 |
| ---- | ---- |
| toolLabel | String! |
| toolValue | String! |
| modules | [[AuditorType!]!](#GetAutoStepConfigDictionary_AuditorType) |

##### <a id="GetAutoStepConfigDictionary_AuditorType"></a>AuditorType

| 名称 | 类型 |
| ---- | ---- |
| moduleLabel | String! |
| moduleValue | String! |
| rules | [String!] |


#### 查询JSON

```json
{
  "query": "query GetAutoStepConfigDictionary{dictionary:viewReportStepSelectList{toolLabel:toolName toolValue:value modules:auditorType{moduleLabel:typeName moduleValue:value rules:selectList}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "dictionary": [
            {
                "toolLabel": "系统自动化分析",
                "toolValue": "SysAuditor",
                "modules": [
                    {
                        "moduleLabel": "安全审计",
                        "moduleValue": "SAFE",
                        "rules": [
                            "内核版本未更新",
                            "核心文件(Core Dump)命令未禁用",
                            "存在SU命令",
                            "进程映射虚拟地址重复",
                            "存在已知漏洞",
                            "Dev目录权限配置不当",
                            "控制台参数配置不当"
                        ]
                    },
                    {
                        "moduleLabel": "用户列表",
                        "moduleValue": "DETAIL_PERMISSION",
                        "rules": null
                    }
                ]
            },
            {
                "toolLabel": "APK自动化分析",
                "toolValue": "ApkPecker",
                "modules": [
                    {
                        "moduleLabel": "安全审计",
                        "moduleValue": "SAFE",
                        "rules": [
                            "WebView File跨域风险",
                            "AES加密模式使用错误风险",
                            "密码硬编码漏洞",
                            "Intent拒绝服务调用风险"
                        ]
                    },
                    {
                        "moduleLabel": "签名信息",
                        "moduleValue": "DETAIL_LICENSE",
                        "rules": null
                    }
                ]
            }
        ]
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetAutoStepConfigDictionary {
  dictionary: viewReportStepSelectList {
    toolLabel: toolName
    toolValue: value
    modules: auditorType {
      moduleLabel: typeName
      moduleValue: value
      rules: selectList
    }
  }
}
</code></pre>
</details>

### <a id="GetLawDictionary"></a>查询法规属性字典

查询法规属性的键值映射，包括法规分类等

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| lawId | String! | 是 | 法规id，示例："law_items;1" |

#### 响应类型

##### <a id="GetLawDictionary_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| dictionary | [ResultRelLawSelector](#GetLawDictionary_ResultRelLawSelector) | 用例生产，级联查询 |

##### <a id="GetLawDictionary_ResultRelLawSelector"></a>ResultRelLawSelector

| 名称 | 类型 |
| ---- | ---- |
| class | [[RelLawSelector]](#GetLawDictionary_RelLawSelector) |

##### <a id="GetLawDictionary_RelLawSelector"></a>RelLawSelector

| 名称 | 类型 |
| ---- | ---- |
| value | String |
| label | String |


#### 查询JSON

```json
{
  "query": "query GetLawDictionary($lawId:String!){dictionary:getProductionLawSelector(casType:\"law\" lawValue:$lawId classifyValue:null requireValue:null){class:resultSelector{value label}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "dictionary": {
            "class": [
                {
                    "value": "959,959,960,961,962",
                    "label": "硬件安全要求"
                },
                {
                    "value": "963",
                    "label": "通信协议与接口安全要求-对外通信协议安全-通信连接安全"
                },
                {
                    "value": "964,964",
                    "label": "通信协议与接口安全要求-对外通信协议安全-通信传输安全"
                }
            ]
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetLawDictionary($lawId: String!) {
  dictionary: getProductionLawSelector(
    casType: &quot;law&quot;
    lawValue: $lawId
    classifyValue: null
    requireValue: null
  ) {
    class: resultSelector {
      value
      label
    }
  }
}
</code></pre>
</details>

### <a id="GetLawClassDictionary"></a>查询法规分类属性字典

查询法规具体某个分类的属性键值映射，包括法规要求等

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| lawId | String! | 是 | 法规id，示例："law_items;1" |
| class | String! | 是 | 法规分类，参考[查询法规属性字典](#GetLawDictionary)中返回的class value |

#### 响应类型

##### <a id="GetLawClassDictionary_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| dictionary | [ResultRelLawSelector](#GetLawClassDictionary_ResultRelLawSelector) | 用例生产，级联查询 |

##### <a id="GetLawClassDictionary_ResultRelLawSelector"></a>ResultRelLawSelector

| 名称 | 类型 |
| ---- | ---- |
| requirements | [[RelLawSelector]](#GetLawClassDictionary_RelLawSelector) |

##### <a id="GetLawClassDictionary_RelLawSelector"></a>RelLawSelector

| 名称 | 类型 |
| ---- | ---- |
| value | String |
| label | String |


#### 查询JSON

```json
{
  "query": "query GetLawClassDictionary($lawId:String!$class:String!){dictionary:getProductionLawSelector(casType:\"classify\" lawValue:$lawId classifyValue:$class requireValue:null){requirements:resultSelector{value label}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "dictionary": {
            "requirements": [
                {
                    "value": "catalogue_items;1",
                    "label": "车载信息交互系统所使用的芯片调试接口应禁用或设置安全访问控制，不存在后门或隐蔽接口。"
                },
                {
                    "value": "catalogue_items;2",
                    "label": "车载信息交互系统所使用的关键芯片(例如:处理器、存储模块、通讯 IC 等用于处理、存储和传输敏感信息的芯片以及安全芯片)应减少暴露管脚。"
                },
                {
                    "value": "catalogue_items;3",
                    "label": "车载信息交互系统所使用的安全芯片之间应减少通信线路的数量(例如: 使用多层电路板的车载信息交互系统可采用内层布线方式隐藏通信线路)。"
                }
            ]
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetLawClassDictionary($lawId: String!, $class: String!) {
  dictionary: getProductionLawSelector(
    casType: &quot;classify&quot;
    lawValue: $lawId
    classifyValue: $class
    requireValue: null
  ) {
    requirements: resultSelector {
      value
      label
    }
  }
}
</code></pre>
</details>

### <a id="CreateCaseDraft"></a>新建用例草稿

新建测试用例草稿，不包括步骤

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| name | String! | 是 | 用例名称 |
| description | String | 否 | 用例描述信息 |
| remediation | String | 否 | 用例修复建议 |
| bindDevice | Int! | 是 | 是否需要绑定设备，值请参考[查询测试用例属性字典](#GetCaseDictionary)中返回的bindDevice值 |
| class | Int! | 是 | 用例分类，值请参考[查询测试用例属性字典](#GetCaseDictionary)中返回的class值 |
| operatingSystem | Int! | 是 | 操作系统类型，值请参考[查询测试用例属性字典](#GetCaseDictionary)中返回的operatingSystem值 |
| riskLevel | Int! | 是 | 风险等级ID，值请参考[查询测试用例属性字典](#GetCaseDictionary)中返回的riskLevel值 |
| testMethod | Int! | 是 | 检测方法，值请参考[查询测试用例属性字典](#GetCaseDictionary)中返回的testMethod值 |
| relLawInfos | [[RelLawInfo]](#RelLawInfo) | 否 | 关联法律法规，值请参考[查询测试用例属性字典](#GetCaseDictionary)中返回的law值 |

#### 响应类型

##### <a id="CreateCaseDraft_Mutation"></a>Mutation

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| caseDraft | [ProductionCaseItem](#CreateCaseDraft_ProductionCaseItem) | 保存用例 |

##### <a id="CreateCaseDraft_ProductionCaseItem"></a>ProductionCaseItem

| 名称 | 类型 |
| ---- | ---- |
| id | String |


#### 查询JSON

```json
{
  "query": "mutation CreateCaseDraft($name:String!$description:String$remediation:String$bindDevice:Int!$class:Int!$operatingSystem:Int!$riskLevel:Int!$testMethod:Int!$relLawInfos:[RelLawInfo]){caseDraft:saveProductionCaseItem(isRelease:false id:\"\" name:$name caseDesc:$description remediation:$remediation bindId:$bindDevice classifyId:$class operatingSystemId:$operatingSystem riskLevelId:$riskLevel testMethod:$testMethod relLawInfos:$relLawInfos){id}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "caseDraft": {
            "id": "case_draft_items;1"
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation CreateCaseDraft($name: String!, $description: String, $remediation: String, $bindDevice: Int!, $class: Int!, $operatingSystem: Int!, $riskLevel: Int!, $testMethod: Int!, $relLawInfos: [RelLawInfo]) {
  caseDraft: saveProductionCaseItem(
    isRelease: false
    id: &quot;&quot;
    name: $name
    caseDesc: $description
    remediation: $remediation
    bindId: $bindDevice
    classifyId: $class
    operatingSystemId: $operatingSystem
    riskLevelId: $riskLevel
    testMethod: $testMethod
    relLawInfos: $relLawInfos
  ) {
    id
  }
}
</code></pre>
</details>

### <a id="SaveCaseDraftStep"></a>保存用例草稿步骤

保存测试用例草稿步骤，示例请求：
```json
{
    "caseDraftId": "case_draft_items;143",
    "stepName": "节点1",
    "stepNodeType": "manual",
    "description": "第一个节点",
    "stepIndex": 1,
    "config": {
        "buttons": [
            {
                "name": "通过",
                "target": "next"
            },
            {
                "name": "不通过",
                "target": "unPassUnDialog"
            }
        ]
    }
}
```

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| caseDraftId | String! | 是 | 测试用例草稿ID，示例："case_draft_items;1" |
| stepName | String! | 是 | 步骤名称 |
| stepNodeType | [StepNodeType!](#StepNodeType) | 是 | 步骤节点类型 |
| description | String! | 是 | 步骤描述信息 |
| stepIndex | Int! | 是 | 步骤在整个用例中的序号，从1开始 |
| config | [StepDraftMetadataInput!](#StepDraftMetadataInput) | 是 | 步骤配置信息 |

#### 响应类型

##### <a id="SaveCaseDraftStep_Mutation"></a>Mutation

| 名称 | 类型 |
| ---- | ---- |
| step | String! |


#### 查询JSON

```json
{
  "query": "mutation SaveCaseDraftStep($caseDraftId:ID!$stepName:String!$stepNodeType:StepNodeType!$description:String!$stepIndex:Int!$config:StepDraftMetadataInput!){step:saveCaseStep(isRelease:false stepInfo:{caseDraftID:$caseDraftId stepName:$stepName stepNodeType:$stepNodeType description:$description stepIndex:$stepIndex metadata:$config})}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "step": "case_step_draft_items;1"
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation SaveCaseDraftStep($caseDraftId: ID!, $stepName: String!, $stepNodeType: StepNodeType!, $description: String!, $stepIndex: Int!, $config: StepDraftMetadataInput!) {
  step: saveCaseStep(
    isRelease: false
    stepInfo: {caseDraftID: $caseDraftId, stepName: $stepName, stepNodeType: $stepNodeType, description: $description, stepIndex: $stepIndex, metadata: $config}
  )
}
</code></pre>
</details>

### <a id="DeleteCaseDraft"></a>删除用例草稿

删除测试用例草稿

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| caseDraftId | String! | 是 | 测试用例草稿ID，示例："case_draft_items;1" |

#### 响应类型

##### <a id="DeleteCaseDraft_Mutation"></a>Mutation

| 名称 | 类型 |
| ---- | ---- |
| caseDraft | Boolean! |


#### 查询JSON

```json
{
  "query": "mutation DeleteCaseDraft($caseDraftId:ID!){caseDraft:deleteCaseDraft(caseDraftId:$caseDraftId)}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation DeleteCaseDraft($caseDraftId: ID!) {
  caseDraft: deleteCaseDraft(caseDraftId: $caseDraftId)
}
</code></pre>
</details>

### <a id="GetCaseDraftList"></a>查询用例草稿列表

查询测试用例草稿列表

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| pageNumber | Int | 否 | 分页参数，表示页序号，初始值为1 |
| pageSize | Int | 否 | 分页参数，表示每页记录的数量 |

#### 响应类型

##### <a id="GetCaseDraftList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| caseDraftList | [CaseDraftList](#GetCaseDraftList_CaseDraftList) | 查询所有草稿箱用例（未发布） |

##### <a id="GetCaseDraftList_CaseDraftList"></a>CaseDraftList

| 名称 | 类型 |
| ---- | ---- |
| count | Int! |
| list | [[CaseDraftItem!]](#GetCaseDraftList_CaseDraftItem) |

##### <a id="GetCaseDraftList_CaseDraftItem"></a>CaseDraftItem

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String |  |
| name | String! |  |
| description | String |  |
| remediation | String |  |
| submitUserName | String! |  |
| submitTime | String! |  |
| modifyUserName | String! |  |
| modifyTime | String! |  |
| canModify | Boolean |  |
| bindId | Int! | 需要/不需要 |
| isBind | Boolean! |  |
| bindName | String! |  |
| classifyName | String |  |
| classifyId | Int |  |
| operatingSystemName | String |  |
| operatingSystemID | Int |  |
| operatingSystemType | String |  |
| riskLevelName | String |  |
| riskLevelType | String |  |
| riskLevelId | Int |  |
| testMethodName | String |  |
| testMethodId | Int |  |
| testMethodType | String |  |


#### 查询JSON

```json
{
  "query": "query GetCaseDraftList($pageNumber:Int=1$pageSize:Int=20){caseDraftList:getAllCaseDraftList(retrieve:{Offset:{CurrentPage:$pageNumber PageSize:$pageSize}SortData:[{SortColumn:\"modifyTime\" DescEnding:true}]}){count list:result{id name description:caseDesc remediation submitUserName submitTime modifyUserName modifyTime canModify bindId isBind bindName classifyName classifyId operatingSystemName operatingSystemID operatingSystemType riskLevelName riskLevelType riskLevelId testMethodName testMethodId testMethodType:testMothodType}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetCaseDraftList($pageNumber: Int = 1, $pageSize: Int = 20) {
  caseDraftList: getAllCaseDraftList(
    retrieve: {Offset: {CurrentPage: $pageNumber, PageSize: $pageSize}, SortData: [{SortColumn: &quot;modifyTime&quot;, DescEnding: true}]}
  ) {
    count
    list: result {
      id
      name
      description: caseDesc
      remediation
      submitUserName
      submitTime
      modifyUserName
      modifyTime
      canModify
      bindId
      isBind
      bindName
      classifyName
      classifyId
      operatingSystemName
      operatingSystemID
      operatingSystemType
      riskLevelName
      riskLevelType
      riskLevelId
      testMethodName
      testMethodId
      testMethodType: testMothodType
    }
  }
}
</code></pre>
</details>

### <a id="ReleaseCaseDraft"></a>发布用例

将测试用例草稿转为已发布用例

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| caseDraftId | String! | 是 |  |

#### 响应类型

##### <a id="ReleaseCaseDraft_Mutation"></a>Mutation

| 名称 | 类型 |
| ---- | ---- |
| success | Boolean! |


#### 查询JSON

```json
{
  "query": "mutation ReleaseCaseDraft($caseDraftId:ID!){success:caseRelease(draftCaseId:$caseDraftId)}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "success": true
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
mutation ReleaseCaseDraft($caseDraftId: ID!) {
  success: caseRelease(draftCaseId: $caseDraftId)
}
</code></pre>
</details>

### <a id="GetCaseDetail"></a>查询用例详情

根据测试用例ID查询单个测试用例详细信息

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| caseId | String! | 是 | 用例id，示例："case_items;1" |

#### 响应类型

##### <a id="GetCaseDetail_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| case | [CaseInfo](#GetCaseDetail_CaseInfo) | 用例信息页 用例信息接口 |

##### <a id="GetCaseDetail_CaseInfo"></a>CaseInfo

| 名称 | 类型 |
| ---- | ---- |
| basicInfo | [CaseCustomItem!](#GetCaseDetail_CaseCustomItem) |
| complianceInfo | [[LawCatalogueBaseDetail]](#GetCaseDetail_LawCatalogueBaseDetail) |
| stepList | [[CaseTestProcess]](#GetCaseDetail_CaseTestProcess) |

##### <a id="GetCaseDetail_CaseCustomItem"></a>CaseCustomItem

| 名称 | 类型 |
| ---- | ---- |
| id | String |
| serialNumber | String |
| name | String! |
| description | String |
| remediation | String |
| bindDeviceLabel | String! |
| classLabel | String |
| operatingSystemLabel | String |
| riskLevelLabel | String |
| submitTime | String! |
| submitUserName | String! |
| canModify | Boolean |
| testMethodName | String |
| testMethodType | String |

##### <a id="GetCaseDetail_LawCatalogueBaseDetail"></a>LawCatalogueBaseDetail

| 名称 | 类型 |
| ---- | ---- |
| lawName | String |
| lawCatalogueId | String |
| lawCatalogueName | String |
| description | String |

##### <a id="GetCaseDetail_CaseTestProcess"></a>CaseTestProcess

| 名称 | 类型 |
| ---- | ---- |
| stepName | String! |
| stepDescription | String! |


#### 查询JSON

```json
{
  "query": "query GetCaseDetail($caseId:ID!){case:caseAllInfo(caseId:$caseId){basicInfo:caseBaseInfo{id serialNumber name description:caseDesc remediation bindDeviceLabel:bindName classLabel:classifyName operatingSystemLabel:operatingSystemName riskLevelLabel:riskLevelName submitTime submitUserName canModify testMethodName testMethodType:testMothodType}complianceInfo:complianceRequire{lawName lawCatalogueId lawCatalogueName:dutyLawCatalogueName description}stepList:caseTestProcessList{stepName stepDescription:stepMd}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "case": {
            "basicInfo": {
                "id": "case_items;1623",
                "serialNumber": "TCZY-011",
                "name": "测试样例",
                "description": "-",
                "remediation": "-",
                "bindDeviceLabel": "不需要",
                "classLabel": "车载以太网安全",
                "operatingSystemLabel": "通用",
                "riskLevelLabel": "高危",
                "submitTime": "2024-01-30 12:13:21",
                "submitUserName": "admin",
                "canModify": true,
                "testMethodName": "手工",
                "testMethodType": "manual"
            },
            "complianceInfo": [
                {
                    "lawName": "车载信息交互系统信息安全技术要求",
                    "lawCatalogueId": "catalogue_items;1",
                    "lawCatalogueName": "车载信息交互系统所使用的芯片调试接口应禁用或设置安全访问控制，不存在后门或隐蔽接口。",
                    "description": "检查是否有存在暴露在PCB板上的JTAG接口、USB接口、UART接口、SPI接口等调试接口，如存在则使用测试工具尝试获取调试权限;\n拆解被测样件设备外壳，取出PCB板，通过5倍率以上的光学放大镜，观察网关PCB板，检查PCB 板硬件是否存在后门或隐蔽接口。"
                }
            ],
            "stepList": [
                {
                    "stepName": "节点1",
                    "stepDescription": "第一个节点"
                }
            ]
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetCaseDetail($caseId: ID!) {
  case: caseAllInfo(caseId: $caseId) {
    basicInfo: caseBaseInfo {
      id
      serialNumber
      name
      description: caseDesc
      remediation
      bindDeviceLabel: bindName
      classLabel: classifyName
      operatingSystemLabel: operatingSystemName
      riskLevelLabel: riskLevelName
      submitTime
      submitUserName
      canModify
      testMethodName
      testMethodType: testMothodType
    }
    complianceInfo: complianceRequire {
      lawName
      lawCatalogueId
      lawCatalogueName: dutyLawCatalogueName
      description
    }
    stepList: caseTestProcessList {
      stepName
      stepDescription: stepMd
    }
  }
}
</code></pre>
</details>

### <a id="GetCaseList"></a>查询用例列表

查询测试用例列表

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| suiteId | String | 否 | 用例集ID，可用于查询用例集下的所有用例 |
| offset | Int | 否 | 分页参数，表示偏移量，默认为0 |
| limit | Int | 否 | 分页参数，表示返回数量，默认为50 |
| search | String | 否 | 搜索参数，用于匹配用例名称或序列号 |
| scenario | String | 否 | 测试场景参数，用于获取该场景下的所有用例 |

#### 响应类型

##### <a id="GetCaseList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| caseList | [CaseCustomItemRep](#GetCaseList_CaseCustomItemRep) | 查询所有用例 |

##### <a id="GetCaseList_CaseCustomItemRep"></a>CaseCustomItemRep

| 名称 | 类型 |
| ---- | ---- |
| count | Int |
| list | [[CaseCustomItem]](#GetCaseList_CaseCustomItem) |

##### <a id="GetCaseList_CaseCustomItem"></a>CaseCustomItem

| 名称 | 类型 |
| ---- | ---- |
| id | String |
| serialNumber | String |
| name | String! |
| description | String |
| remediation | String |
| submitUserName | String! |
| submitTime | String! |
| canModify | Boolean |
| needDevice | Boolean! |
| classifyName | String |
| operatingSystemName | String |
| riskLevelName | String |
| testMethodName | String |


#### 查询JSON

```json
{
  "query": "fragment CaseListItem on CaseCustomItemRep{count list:resultList{id serialNumber name description:caseDesc remediation submitUserName submitTime canModify needDevice:isBind classifyName operatingSystemName riskLevelName testMethodName}}query GetCaseList($suiteId:ID$offset:Int=0$limit:Int=50$search:String=\"\"$scenario:String){caseList:getAllCaseList(teamId:\"team_items;1\" suiteId:$suiteId offset:{offset:$offset limit:$limit}search:{retrieveData:[{RetrieveColumn:\"allName\" RetrieveValue:$search}]sortData:[{SortColumn:\"serialNumber\" SortOrder:ASC}]}scenario:$scenario){...CaseListItem}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
fragment CaseListItem on CaseCustomItemRep {
  count
  list: resultList {
    id
    serialNumber
    name
    description: caseDesc
    remediation
    submitUserName
    submitTime
    canModify
    needDevice: isBind
    classifyName
    operatingSystemName
    riskLevelName
    testMethodName
  }
}

query GetCaseList($suiteId: ID, $offset: Int = 0, $limit: Int = 50, $search: String = &quot;&quot;, $scenario: String) {
  caseList: getAllCaseList(
    teamId: &quot;team_items;1&quot;
    suiteId: $suiteId
    offset: {offset: $offset, limit: $limit}
    search: {retrieveData: [{RetrieveColumn: &quot;allName&quot;, RetrieveValue: $search}], sortData: [{SortColumn: &quot;serialNumber&quot;, SortOrder: ASC}]}
    scenario: $scenario
  ) {
    ...CaseListItem
  }
}
</code></pre>
</details>

### <a id="GetCaseStepDetail"></a>查询用例步骤详情

查询测试用例步骤详情

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| stepId | String! | 是 | 步骤id，示例："case_step_items;1" |
| isRelease | Boolean! | 否 | 用例是否已发布，默认为true |

#### 响应类型

##### <a id="GetCaseStepDetail_Query"></a>Query

| 名称 | 类型 |
| ---- | ---- |
| detail | [StepDraftInfo](#GetCaseStepDetail_StepDraftInfo) |

##### <a id="GetCaseStepDetail_StepDraftInfo"></a>StepDraftInfo

| 名称 | 类型 |
| ---- | ---- |
| id | String! |
| stepName | String! |
| stepNodeType | [StepNodeType!](#StepNodeType) |
| description | String! |
| stepIndex | Int! |
| testReference | String |
| uploadFileURL | String! |
| metadata | [StepDraftMetadata!](#GetCaseStepDetail_StepDraftMetadata) |

##### <a id="GetCaseStepDetail_StepDraftMetadata"></a>StepDraftMetadata

| 名称 | 类型 |
| ---- | ---- |
| buttons | [[Button]!](#GetCaseStepDetail_Button) |
| keyWords | [[Keyword]!](#GetCaseStepDetail_Keyword) |
| mainScriptFile | [ScriptFile](#GetCaseStepDetail_ScriptFile) |
| subScriptFiles | [[ScriptFile!]](#GetCaseStepDetail_ScriptFile) |
| analysisReportMap | [AnalysisReportMap](#GetCaseStepDetail_AnalysisReportMap) |

##### <a id="GetCaseStepDetail_Button"></a>Button

| 名称 | 类型 |
| ---- | ---- |
| name | String! |
| target | [ButtonTarget!](#ButtonTarget) |
| content | String! |

##### <a id="GetCaseStepDetail_Keyword"></a>Keyword

| 名称 | 类型 |
| ---- | ---- |
| name | String! |
| word | String! |
| index | Int! |
| sourceType | [KeywordType!](#KeywordType) |
| defaultValue | String! |

##### <a id="GetCaseStepDetail_ScriptFile"></a>ScriptFile

| 名称 | 类型 |
| ---- | ---- |
| fmId | Int! |
| fileName | String! |
| isDel | Boolean! |

##### <a id="GetCaseStepDetail_AnalysisReportMap"></a>AnalysisReportMap

| 名称 | 类型 |
| ---- | ---- |
| auditTool | String! |
| auditType | String! |
| stepRulesMapping | [String!] |


#### 查询JSON

```json
{
  "query": "query GetCaseStepDetail($stepId:ID!$isRelease:Boolean!=true){detail:caseStepInfo(id:$stepId isRelease:$isRelease){id stepName stepNodeType description stepIndex testReference uploadFileURL metadata{buttons{name target content}keyWords{name word index sourceType defaultValue}mainScriptFile{fmId fileName isDel}subScriptFiles{fmId fileName isDel}analysisReportMap{auditTool auditType stepRulesMapping}}}}",
  "variables": {}
}
```
#### 响应JSON示例

```json
{
    "data": {
        "detail": {
            "id": "case_step_item;1",
            "stepName": "节点0",
            "stepNodeType": "viewReport",
            "description": "自动扫描高危端口",
            "stepIndex": 1,
            "testReference": "可以点击报告，查看扫描结果详情",
            "uploadFileURL": "/file_server/api_v1/uploadPerpetualFile",
            "metadata": {
                "buttons": [
                    {
                        "name": "通过",
                        "target": "passUnDialog",
                        "content": ""
                    },
                    {
                        "name": "不通过",
                        "target": "unPassUnDialog",
                        "content": ""
                    }
                ],
                "keyWords": [],
                "mainScriptFile": null,
                "subScriptFiles": [],
                "analysisReportMap": {
                    "auditTool": "test audit",
                    "auditType": "端口检测",
                    "stepRulesMapping": [
                        "高风险端口扫描"
                    ]
                }
            }
        }
    }
}
```

#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetCaseStepDetail($stepId: ID!, $isRelease: Boolean! = true) {
  detail: caseStepInfo(id: $stepId, isRelease: $isRelease) {
    id
    stepName
    stepNodeType
    description
    stepIndex
    testReference
    uploadFileURL
    metadata {
      buttons {
        name
        target
        content
      }
      keyWords {
        name
        word
        index
        sourceType
        defaultValue
      }
      mainScriptFile {
        fmId
        fileName
        isDel
      }
      subScriptFiles {
        fmId
        fileName
        isDel
      }
      analysisReportMap {
        auditTool
        auditType
        stepRulesMapping
      }
    }
  }
}
</code></pre>
</details>

### <a id="GetSuiteList"></a>查询用例集列表

查询用例集列表

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| offset | Int | 否 | 分页参数，表示偏移量，默认为0 |
| limit | Int | 否 | 分页参数，表示返回数量，默认为50 |
| search | String | 否 | 搜索参数，用于匹配用例集名称 |

#### 响应类型

##### <a id="GetSuiteList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| suiteList | [SuiteCustomItemRep](#GetSuiteList_SuiteCustomItemRep) | 查询用例集列表，包含原来的 |

##### <a id="GetSuiteList_SuiteCustomItemRep"></a>SuiteCustomItemRep

| 名称 | 类型 |
| ---- | ---- |
| count | Int |
| list | [[SuiteCustomItem]](#GetSuiteList_SuiteCustomItem) |

##### <a id="GetSuiteList_SuiteCustomItem"></a>SuiteCustomItem

| 名称 | 类型 |
| ---- | ---- |
| id | String |
| name | String! |
| lawType | Int |
| style | Boolean |
| descriptionInfo | String |
| canModify | Boolean |
| caseCount | Int |
| updateTime | String |
| createTime | String |
| createUser | String |
| createUserId | Int |


#### 查询JSON

```json
{
  "query": "query GetSuiteList($offset:Int=0$limit:Int=20$search:String=\"\"){suiteList:getUserCustomCaseSuiteList(teamId:\"team_items;1\" search:{offset:{offset:$offset limit:$limit}searchField:\"name\" search:$search}){count list:resultList{id name lawType:layType style descriptionInfo canModify caseCount updateTime createTime createUser createUserId}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetSuiteList($offset: Int = 0, $limit: Int = 20, $search: String = &quot;&quot;) {
  suiteList: getUserCustomCaseSuiteList(
    teamId: &quot;team_items;1&quot;
    search: {offset: {offset: $offset, limit: $limit}, searchField: &quot;name&quot;, search: $search}
  ) {
    count
    list: resultList {
      id
      name
      lawType: layType
      style
      descriptionInfo
      canModify
      caseCount
      updateTime
      createTime
      createUser
      createUserId
    }
  }
}
</code></pre>
</details>

### <a id="GetFileList"></a>查询文件列表

查询文件列表，不包括脚本文件

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| pageNumber | Int | 否 | 分页参数，表示页序号，初始值为1 |
| pageSize | Int | 否 | 分页参数，表示每页记录的数量 |

#### 响应类型

##### <a id="GetFileList_Query"></a>Query

| 名称 | 类型 |
| ---- | ---- |
| fileList | [FileManagementRsp!](#GetFileList_FileManagementRsp) |

##### <a id="GetFileList_FileManagementRsp"></a>FileManagementRsp

| 名称 | 类型 |
| ---- | ---- |
| count | Int! |
| list | [[FileManagementItem]!](#GetFileList_FileManagementItem) |

##### <a id="GetFileList_FileManagementItem"></a>FileManagementItem

| 名称 | 类型 |
| ---- | ---- |
| id | String! |
| fileSize | Int! |
| fileSizeFormat | String! |
| createTimeFormat | String! |
| addMethod | String! |
| createUser | String! |
| createTime | [Time!](#Time) |
| addMethodInt | Int! |
| name | String! |
| scriptType | [Int] |


#### 查询JSON

```json
{
  "query": "query GetFileList($pageNumber:Int=1$pageSize:Int=20){fileList:getFileManagementList(fileType:\"file\" retrieve:{Offset:{CurrentPage:$pageNumber PageSize:$pageSize}}){count list:results{id:ID fileSize fileSizeFormat createTimeFormat addMethod createUser createTime addMethodInt name scriptType}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetFileList($pageNumber: Int = 1, $pageSize: Int = 20) {
  fileList: getFileManagementList(
    fileType: &quot;file&quot;
    retrieve: {Offset: {CurrentPage: $pageNumber, PageSize: $pageSize}}
  ) {
    count
    list: results {
      id: ID
      fileSize
      fileSizeFormat
      createTimeFormat
      addMethod
      createUser
      createTime
      addMethodInt
      name
      scriptType
    }
  }
}
</code></pre>
</details>

### <a id="GetScriptFileList"></a>查询脚本文件列表

查询脚本文件列表

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| pageNumber | Int | 否 | 分页参数，表示页序号，初始值为1 |
| pageSize | Int | 否 | 分页参数，表示每页记录的数量 |

#### 响应类型

##### <a id="GetScriptFileList_Query"></a>Query

| 名称 | 类型 |
| ---- | ---- |
| scriptFileList | [FileManagementRsp!](#GetScriptFileList_FileManagementRsp) |

##### <a id="GetScriptFileList_FileManagementRsp"></a>FileManagementRsp

| 名称 | 类型 |
| ---- | ---- |
| count | Int! |
| list | [[FileManagementItem]!](#GetScriptFileList_FileManagementItem) |

##### <a id="GetScriptFileList_FileManagementItem"></a>FileManagementItem

| 名称 | 类型 |
| ---- | ---- |
| id | String! |
| fileSize | Int! |
| fileSizeFormat | String! |
| createTimeFormat | String! |
| addMethod | String! |
| createUser | String! |
| createTime | [Time!](#Time) |
| addMethodInt | Int! |
| name | String! |
| scriptType | [Int] |


#### 查询JSON

```json
{
  "query": "query GetScriptFileList($pageNumber:Int=1$pageSize:Int=20){scriptFileList:getFileManagementList(fileType:\"script\" retrieve:{Offset:{CurrentPage:$pageNumber PageSize:$pageSize}}){count list:results{id:ID fileSize fileSizeFormat createTimeFormat addMethod createUser createTime addMethodInt name scriptType}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
query GetScriptFileList($pageNumber: Int = 1, $pageSize: Int = 20) {
  scriptFileList: getFileManagementList(
    fileType: &quot;script&quot;
    retrieve: {Offset: {CurrentPage: $pageNumber, PageSize: $pageSize}}
  ) {
    count
    list: results {
      id: ID
      fileSize
      fileSizeFormat
      createTimeFormat
      addMethod
      createUser
      createTime
      addMethodInt
      name
      scriptType
    }
  }
}
</code></pre>
</details>

### <a id="GetUserList"></a>查询用户列表

查询用户列表

#### 请求参数

| 名称 | 类型 | 是否必填 | 描述 |
| ---- | ---- | ------ | ---- |
| offset | Int! | 否 | 分页参数，表示偏移量，默认为0 |
| limit | Int! | 否 | 分页参数，表示返回数量，默认为50 |
| search | String | 否 | 搜索参数，用于匹配用户名 |

#### 响应类型

##### <a id="GetUserList_Query"></a>Query

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| management | [Management!](#GetUserList_Management) | Sysauditor management. |

##### <a id="GetUserList_Management"></a>Management

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| user | [UserConnection](#GetUserList_UserConnection) | 用户分页查询 |

##### <a id="GetUserList_UserConnection"></a>UserConnection

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| nodes | [[User!]](#GetUserList_User) | 用户列表 |
| totalCount | Int! | 总个数 |
| fieldValues | [Map](#Map) | 获取指定字段的值列表，用于过滤筛选，支持批量获取<br>输入示例：{fields: ["userRole"]}<br>返回示例：{"userRole": [ "Admin", "AssetProducer", "SuperAdmin"]} |

##### <a id="GetUserList_User"></a>User

| 名称 | 类型 | 描述 |
| ---- | ---- | ----------- |
| id | String! |  |
| username | String! | Username. |
| nickname | String! | Nickname. |
| lastLoginTime | [Time!](#Time) | Last login time. |


#### 查询JSON

```json
{
  "query": "fragment UserListObject on User{id username nickname lastLoginTime}query GetUserList($offset:Int!=0$limit:Int!=50$search:String){management{user(offset:{offset:$offset limit:$limit}search:$search orderBy:null filterFields:null){nodes{...UserListObject}totalCount fieldValues(fields:[\"userRole\"])}}}",
  "variables": {}
}
```
#### 查询

<details>
<summary>展开查看</summary>
<pre><code>
fragment UserListObject on User {
  id
  username
  nickname
  lastLoginTime
}

query GetUserList($offset: Int! = 0, $limit: Int! = 50, $search: String) {
  management {
    user(
      offset: {offset: $offset, limit: $limit}
      search: $search
      orderBy: null
      filterFields: null
    ) {
      nodes {
        ...UserListObject
      }
      totalCount
      fieldValues(fields: [&quot;userRole&quot;])
    }
  }
}
</code></pre>
</details>

## <a id="_common_types"></a>通用类型

### <a id="_input"></a>输入类型

#### <a id="RelLawInfo"></a>RelLawInfo

| 名称 | 类型 | 是否必填 | 描述 |
| --- | --- | ------ | --- |
| lawId | String | 否 |  |
| requireId | String | 否 |  |


#### <a id="StepDraftMetadataInput"></a>StepDraftMetadataInput

| 名称 | 类型 | 是否必填 | 描述 |
| --- | --- | ------ | --- |
| buttons | [[ButtonInput!]](#ButtonInput) | 否 |  |
| keyWords | [[KeywordInput!]](#KeywordInput) | 否 |  |
| mainScriptFile | [ScriptFileInput](#ScriptFileInput) | 否 |  |
| subScriptFiles | [[ScriptFileInput!]](#ScriptFileInput) | 否 |  |
| AnalysisReportMap | [AnalysisReportMapInput](#AnalysisReportMapInput) | 否 |  |


#### <a id="ButtonInput"></a>ButtonInput

| 名称 | 类型 | 是否必填 | 描述 |
| --- | --- | ------ | --- |
| name | String! | 是 |  |
| target | [ButtonTarget!](#ButtonTarget) | 是 |  |


#### <a id="KeywordInput"></a>KeywordInput

| 名称 | 类型 | 是否必填 | 描述 |
| --- | --- | ------ | --- |
| name | String! | 是 |  |
| word | String! | 是 |  |
| index | Int! | 是 |  |
| sourceType | [KeywordType!](#KeywordType) | 是 |  |
| defaultValue | String! | 是 |  |


#### <a id="ScriptFileInput"></a>ScriptFileInput

| 名称 | 类型 | 是否必填 | 描述 |
| --- | --- | ------ | --- |
| fmId | Int! | 是 |  |
| fileName | String! | 是 |  |


#### <a id="AnalysisReportMapInput"></a>AnalysisReportMapInput

| 名称 | 类型 | 是否必填 | 描述 |
| --- | --- | ------ | --- |
| auditTool | String! | 是 |  |
| auditType | String! | 是 |  |
| stepRulesMapping | [String!] | 否 |  |


### <a id="_enum"></a>枚举类型

#### <a id="StepNodeType"></a>StepNodeType

| 名称 |
| ---- |
| scriptExe |
| manual |
| viewReport |


#### <a id="ButtonTarget"></a>ButtonTarget

| 名称 |
| ---- |
| next |
| unPassDialog |
| unPassUnDialog |
| passDialog |
| passUnDialog |


#### <a id="KeywordType"></a>KeywordType

| 名称 |
| ---- |
| static |
| userInput |
| package |
| deviceId |


#### <a id="CommonStatus"></a>CommonStatus

| 名称 |
| ---- |
| Ready |
| InProgress |
| Completed |


### <a id="_scalar"></a>标量类型

#### <a id="Time"></a>Time

| 名称 | 描述 |
| ---- | ----------- |
| Time | 自定义的ISO-8601时间类型, 示例：2021-03-03T18:04:49+08:00 |


#### <a id="Map"></a>Map

| 名称 | 描述 |
| ---- | ----------- |
| Map | 自定义的键值映射类型 |


### <a id="_union"></a>联合类型

#### <a id="StepPluginResult"></a>StepPluginResult

| 包含类型 | 
| ---- |
| StepPluginJSONResult |
| StepPluginURLResult |
| StepPluginHTMLResult |


## <a id="error_code"></a>错误码

* error-permission：用户无权限
* error-null—field：字段不可空
* error-exists—object：目标已存在
* error-token-invalid：无效Token
* error-busy—object：目标正在工作中

## <a id="example"></a>示例脚本

```bash
  #!/bin/bash
  # 本脚本用于在车联网安全检测平台创建终端检测项目样例，需要检测终端已连接平台
  #
  # 脚本依赖于以下参数：
  # 平台侧：地址/登录用户名/登录密码
  # 目标设备：IP/端口/用户名/密码，检测终端会通过SSH连接到目标设备
  #
  # 脚本会通过API依次执行以下操作：
  # 登录/创建API Token/新建样例操作系统/查询操作系统列表/查询终端列表/连接目标设备/查询用例集/新建终端检测项目

  # 请修改以下TODO参数
  VVMP_ADDR=TODO # 请修改为VVMP地址，例如：http://192.168.0.1:8089
  VVMP_USER=TODO # 请修改为VVMP用户名，例如：admin
  VVMP_PASS=TODO # 请修改为VVMP密码，例如：adminpwd

  IP=TODO       # 请修改为目标设备IP，例如：192.168.127.76
  PORT=TODO     # 请修改为目标设备端口，例如：22
  USERNAME=TODO # 请修改为目标设备用户名，例如：testuser
  PASSWORD=TODO # 请修改为目标设备密码，例如：testpwd

  function check_command() {
      if ! command -v $1 &>/dev/null; then
          echo "$1 is required, please install $1 first"
          exit 1
      fi
  }

  check_command curl
  check_command jq

  set -eo pipefail

  ENDPOINT=$VVMP_ADDR/query

  # 登录
  echo "登录..."
  payload='{
      "query": "mutation Login($username: String!, $password: String!) {loginByPassword(input: {username: $username, password: $password}) {token}}",
      "variables": {"username": "'$VVMP_USER'", "password": "'$VVMP_PASS'"}
  }'
  loginToken=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -d "$payload" \
      $ENDPOINT | jq -r '.data.loginByPassword.token')

  echo -e "\n创建API Token..."
  payload='{
      "query": "mutation createAPIToken($input: CreateTokenInput!) { token{ createToken(input:$input){ token } } }",
      "variables": {
          "input": {
              "description": ""
          }
      }
  }'
  APITOKEN=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -H "Authorization: Bearer $loginToken" \
      -d "$payload" \
      $ENDPOINT | jq -r '.data.token.createToken.token')
  echo "创建完成"

  # 新建样例操作系统
  echo -e "\n新建样例操作系统..."
  url=$VVMP_ADDR/assets/api_v1/system/createSystem
  system_name="测试样例$(date +%s)"
  payload='{"name":"'$system_name'","systemType":1,"systemCoreVersion":"6.5","belongAutoParts":[],"fileName":""}'
  resp=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -H "Authorization: Bearer $APITOKEN" \
      -d $payload \
      $url | jq .)
  echo "新建结果："
  echo $resp | jq .

  # 查询操作系统列表
  echo -e "\n查询样例操作系统..."
  system=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -H "Authorization: Bearer $APITOKEN" \
      -d '{
          "query": "query GetSystemList{list:projectSelectorList(teamId:\"team_items;1\"){systemGroup:testObject{systemTypeId:autoPartsId systemTypeName:autoPartsName systemList:systemChild{systemId systemName systemVersion hasFile:hasFileUrl}}}}",
          "variables": {}
      }' \
      $ENDPOINT | jq '.data.list.systemGroup[] | select(.systemTypeName == "Linux") | {systemTypeId, systemTypeName, systemId: .systemList[0].systemId}')
  echo "查询结果："
  echo $system | jq .

  # 查询终端列表
  echo -e "\n查询终端列表..."
  client=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -H "Authorization: Bearer $APITOKEN" \
      -d '{
          "query": "query GetClientList{result:projectSelectorList(teamId:\"team_items;1\"){clientWithDeviceList:clientLinux{clientId clientName deviceList:clientChild{deviceId deviceName isUsable}}}}",
          "variables": {}
      }' \
      $ENDPOINT | jq '.data.result.clientWithDeviceList[0]')
  echo "查询结果："
  echo $client | jq .

  # 连接目标设备
  echo -e "\n连接目标设备..."
  client_id=$(echo $client | jq -r '.clientId')
  payload='{
      "query": "query DetectDevice($clientId:String!$connectType:String!$ip:String!$port:Int!$username:String!$password:String$certUrl:String){checkDeviceOnline(teamId:\"team_items;1\" clientId:$clientId connectType:$connectType connectIP:$ip connectPort:$port connectUser:$username connectPassword:$password connectCertificateUrl:$certUrl deviceType:\"linux\"){isOnline deviceType deviceId deviceName clientId}}",
      "variables": {
          "clientId": "'$client_id'",
          "connectType": "pwd",
          "ip": "'$IP'",
          "port": '$PORT',
          "username": "'$USERNAME'",
          "password": "'$PASSWORD'"
      }
  }'
  echo $payload | jq .variables
  device=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -H "Authorization: Bearer $APITOKEN" \
      -d "$payload" \
      $ENDPOINT | jq .)
  echo "连接结果："
  echo $device | jq .
  if [ $(echo $device | jq -r .data.checkDeviceOnline.isOnline) != "true" ]; then
      echo "设备未在线"
      exit 1
  fi

  # 查询用例集
  echo -e "\n查询用例集..."
  law=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -H "Authorization: Bearer $APITOKEN" \
      -d '{
          "query": "query GetSuiteList($offset:Int=0$limit:Int=20$search:String=\"\"){suiteList:getUserCustomCaseSuiteList(teamId:\"team_items;1\" search:{offset:{offset:$offset limit:$limit}searchField:\"name\" search:$search}){count list:resultList{id name lawType:layType style descriptionInfo canModify caseCount updateTime createTime createUser createUserId}}}",
          "variables": {}
      }' \
      $ENDPOINT | jq '.data.suiteList.list[] | select(.name == "车载信息交互系统信息安全技术要求") | {id, name}')
  echo "查询结果："
  echo $law | jq .

  # 新建终端检测项目
  echo -e "\n新建终端检测项目..."
  name="检测项目样例$(date +%s)"
  lawId=$(echo $law | jq -r .id)
  systemId=$(echo $system | jq -r .systemId)
  clientId=$(echo $device | jq -r .data.checkDeviceOnline.clientId)
  deviceId=$(echo $device | jq -r .data.checkDeviceOnline.deviceId)
  payload='{
  "query": "fragment ProjectBasicObject on Project{id name description status}mutation NewClientTestProject($name:String!$lawId:ID!$principalUserId:ID!$systemId:ID!$clientId:String!$deviceId:String!$connectType:String!$ip:String!$port:Int!$username:String!$password:String$certUrl:String){projectMutation:teamProject(id:\"team_items;1\"){project:createProject(input:{testMethod:Client name:$name lawId:$lawId principalUserId:$principalUserId systemId:$systemId clientId:$clientId deviceId:$deviceId linuxConnectType:$connectType linuxConnectIP:$ip linuxConnectPort:$port linuxConnectUser:$username linuxConnectPassword:$password linuxConnectCertificateUrl:$certUrl}){...ProjectBasicObject}}}",
  "variables": {
      "name": "'$name'",
      "lawId": "'$lawId'",
      "principalUserId": "user_items;1",
      "systemId": "'$systemId'",
      "clientId": "'$clientId'",
      "deviceId": "'$deviceId'",
      "connectType": "pwd",
      "ip": "'$IP'",
      "port": '$PORT',
      "username": "'$USERNAME'",
      "password": "'$PASSWORD'"
  }
  }'
  project=$(curl -sX POST \
      -H "Content-Type: application/json" \
      -H "Authorization: Bearer $APITOKEN" \
      -d "$payload" \
      $ENDPOINT | jq .)
  echo "新建结果："
  echo $project | jq .
```

## <a id="changelog"></a>更新日志

### 202403
#### 新增
* 支持[快速创建项目](#FastTestProject)
#### 调整
* [查询用例列表](#GetCaseList) 新增 `scenario` 参数，用于查询具体测试场景下的用例列表
### 202401
初始版本
